///////////////////////////////////////////////////////////////////////////////
//
//  Copyright (c) 2007, 2010 Michael A. Jackson for BlueQuartz Software
//  All rights reserved.
//  BSD License: http://www.opensource.org/licenses/bsd-license.html
//
//  This code was written under United States Air Force Contract number
//                           F33615-03-C-5220
//
///////////////////////////////////////////////////////////////////////////////

#include "ZeissMetaEntry.h"
#include <ZeissXML/ZeissTagMapping.h>


#include <MXA/Common/LogTime.h>
#ifdef ZEISS_HDF_SUPPORT
#include <MXA/HDF5/H5Lite.h>
#endif
#include <MXA/Utilities/StringUtils.h>

#define ZME_CHECK_ATTRIBUTE_ADDITION(ds, attr, value) \
if ( err < 0 ) {\
  std::cout << logTime() << "Error adding attribute " << attr << " with value " << value \
  <<   " to data set " << ds << std::endl; retErr = err;}

// -----------------------------------------------------------------------------
//
// -----------------------------------------------------------------------------
#define VALUE_DEFINITION(className, _value)\
bool className::setValue(const std::string &value)\
{\
  return StringUtils::stringToNum(_value, value);\
}\
\
bool className::setValue(int32_t value)\
{\
  _value = value;\
  return true;\
}\
int32_t className::getValue() { \
  return _value; }

// -----------------------------------------------------------------------------
//
// -----------------------------------------------------------------------------
#define WriteHDF5Attribute_Implementation(thisClass)\
int thisClass::writeHDF5Attribute(hid_t fileId, const std::string &datasetPath)\
{\
  ZeissTagMapping::Pointer tagMap = ZeissTagMapping::instance();\
  std::string tagName = tagMap->nameForId(this->getZeissIdTag());\
  if (tagName.empty() == true) { std::cout << "writeHDF5Attribute: Error writing attribute. No zeiss id was found "\
    << " for id=" << getZeissIdTag() << std::endl; return -19; } \
  int32_t err = H5Lite::writeScalarAttribute(fileId, datasetPath, tagName, _value );\
  if ( err < 0 ) {\
    std::cout << logTime() << "Error writing attribute " << tagName << " with value " << _value \
    <<   " to data set " << datasetPath << std::endl; return err;}\
    return err;\
}

#define ReadHDF5Attribute_DEFINITION(type, thisClass)\
int thisClass::readHDF5Attribute(hid_t fileId, const std::string &datasetPath) { \
  ZeissTagMapping::Pointer tagMap = ZeissTagMapping::instance();\
  std::string tagName = tagMap->nameForId(getZeissIdTag());\
  if (tagName.empty() == true) { std::cout << "readHDF5Attribute: Error reading attribute. No zeiss id was found "\
    << " for id=" << getZeissIdTag() << std::endl; return -19; } \
  int32_t err = H5Lite::readScalarAttribute<type>(fileId, datasetPath, tagName, _value);\
  if ( err < 0 ) {\
    std::cout << logTime() << "Error reading attribute " << tagName << " from data set " << datasetPath << std::endl;\
    return err;}\
  return err;\
}


#if 1
#define WriteHDF5Attribute_StrImplementation(thisClass)\
int thisClass::writeHDF5Attribute(hid_t fileId, const std::string &datasetPath)\
{\
  ZeissTagMapping::Pointer tagMap = ZeissTagMapping::instance();\
  std::string tagName = tagMap->nameForId(getZeissIdTag());\
  if (tagName.empty() == true) { std::cout << "writeHDF5Attribute: Error writing attribute. No zeiss id was found "\
    << " for id=" << getZeissIdTag() << std::endl; return -19; } \
  int32_t err = H5Lite::writeStringAttribute(fileId, datasetPath, tagName, _value );\
  if ( err < 0 ) {\
    std::cout << logTime() << "Error adding attribute " << tagName << " with value " << _value \
    <<   " to data set " << datasetPath << std::endl; return err;}\
    return err;\
}



#define ReadHDF5Attribute_STR_DEFINITION(thisClass)\
int thisClass::readHDF5Attribute(hid_t fileId, const std::string &datasetPath) { \
  ZeissTagMapping::Pointer tagMap = ZeissTagMapping::instance();\
  std::string tagName = tagMap->nameForId(getZeissIdTag());\
  if (tagName.empty() == true) { std::cout << "readHDF5Attribute: Error reading attribute. No zeiss id was found "\
    << " for id=" << getZeissIdTag() << std::endl; return -19; } \
  int32_t err = H5Lite::readStringAttribute(fileId, datasetPath, tagName, _value);\
  if ( err < 0 ) {\
    std::cout << logTime() << "Error reading attribute " << tagName << " from data set " << datasetPath << std::endl;\
    return err;}\
  return err;\
}
#else

#define ReadHDF5Attribute_STR_DEFINITION(thisClass)\
int thisClass::readHDF5Attribute(hid_t fileId, const std::string &datasetPath) { \
std::cout << "NOT IMPLEMENTED" << std::endl; return -1;}

#define WriteHDF5Attribute_StrImplementation(thisClass)\
int thisClass::writeHDF5Attribute(hid_t fileId, const std::string &datasetPath)\
{ std::cout << "NOT IMPLEMENTED" << std::endl; return -1;}

#endif


// -----------------------------------------------------------------------------
// Int32ZeissMetaEntry Implementations
// -----------------------------------------------------------------------------
VALUE_DEFINITION(Int32ZeissMetaEntry, _value);
#ifdef ZEISS_HDF_SUPPORT
WriteHDF5Attribute_Implementation(Int32ZeissMetaEntry);
ReadHDF5Attribute_DEFINITION(int32_t, Int32ZeissMetaEntry);
#endif

// -----------------------------------------------------------------------------
// Int64ZeissMetaEntry Implementations
// -----------------------------------------------------------------------------
VALUE_DEFINITION(Int64ZeissMetaEntry, _value);
#ifdef ZEISS_HDF_SUPPORT
WriteHDF5Attribute_Implementation(Int64ZeissMetaEntry);
ReadHDF5Attribute_DEFINITION(int64_t, Int64ZeissMetaEntry);
#endif

// -----------------------------------------------------------------------------
// FloatZeissMetaEntry Implementations
// -----------------------------------------------------------------------------
#ifdef ZEISS_HDF_SUPPORT
WriteHDF5Attribute_Implementation(FloatZeissMetaEntry);
ReadHDF5Attribute_DEFINITION(float, FloatZeissMetaEntry);
#endif

// -----------------------------------------------------------------------------
// StringZeissMetaEntry Implementations
// -----------------------------------------------------------------------------
#ifdef ZEISS_HDF_SUPPORT
WriteHDF5Attribute_StrImplementation(StringZeissMetaEntry);
ReadHDF5Attribute_STR_DEFINITION(StringZeissMetaEntry);
#endif

