///////////////////////////////////////////////////////////////////////////////
//
//  Copyright (c) 2007, 2010 Michael A. Jackson for BlueQuartz Software
//  All rights reserved.
//  BSD License: http://www.opensource.org/licenses/bsd-license.html
//
//  This code was written under United States Air Force Contract number
//                           F33615-03-C-5220
//
///////////////////////////////////////////////////////////////////////////////

#include "ZeissTagMapping.h"
//#include <ZeissXML/R3DConstants.h>
#include <ZeissXML/ZeissMetaEntry.h>
#include <ZeissXML/ZeissMetaFactory.h>


// -----------------------------------------------------------------------------
//
// -----------------------------------------------------------------------------
ZeissTagMapping::ZeissTagMapping()
{
  initIdNameMap();
  initNameIdMap();
  initFactoryMap();
}

// -----------------------------------------------------------------------------
//
// -----------------------------------------------------------------------------
ZeissTagMapping::~ZeissTagMapping()
{
}

// -----------------------------------------------------------------------------
//
// -----------------------------------------------------------------------------
ZeissTagMapping::Pointer ZeissTagMapping::instance()
{
  static ZeissTagMapping::Pointer singleton;

  if (singleton.get() == NULL)
  {
    singleton.reset (new ZeissTagMapping() );
  }
  return singleton;
}


// -----------------------------------------------------------------------------
//
// -----------------------------------------------------------------------------
std::string ZeissTagMapping::nameForId(int idTag)
{
  std::map<int, std::string>::const_iterator i = _idNameMap.find(idTag);
  if (i != _idNameMap.end())
  {
    return (*i).second;
  }
  return std::string("");

}

// -----------------------------------------------------------------------------
//
// -----------------------------------------------------------------------------
int ZeissTagMapping::idForName(const std::string &name)
{
  ZeissNameIdMap::const_iterator i = _nameIdMap.find(name);
  if (i != _nameIdMap.end())
  {
    return (*i).second;
  }
  return -1;
}

// -----------------------------------------------------------------------------
//
// -----------------------------------------------------------------------------
ZeissMetaFactory::Pointer ZeissTagMapping::factoryForId(int idTag)
{
  ZeissFactoryMap::const_iterator i = _idFactoryMap.find(idTag);
  if (i != _idFactoryMap.end())
  {
    return (*i).second;
  }

  return ZeissMetaFactory::NullPointer();
}

// -----------------------------------------------------------------------------
//
// -----------------------------------------------------------------------------
AbstractZeissMetaData::Pointer ZeissTagMapping::metaDataForTagName(const std::string &name)
{
  int idTag = idForName(name);
  if (idTag < 0)
  {
    return AbstractZeissMetaData::NullPointer();
  }

  ZeissMetaFactory::Pointer f = _idFactoryMap[idTag];
  if (NULL != f.get() )
  {
    AbstractZeissMetaData::Pointer ptr = f->createMetaEntry();
    ptr->setZeissIdTag(idTag);
    return ptr;
  }
  return AbstractZeissMetaData::NullPointer();
}

// -----------------------------------------------------------------------------
//
// -----------------------------------------------------------------------------
AbstractZeissMetaData::Pointer ZeissTagMapping::metaDataForId(int idTag, const std::string &value)
{
  ZeissMetaFactory::Pointer f = _idFactoryMap[idTag];
  if (NULL != f.get() )
  {
    AbstractZeissMetaData::Pointer ptr = f->createMetaEntry();
    ptr->setZeissIdTag(idTag);
    ptr->setValue(value);
    return ptr;
  }
  return AbstractZeissMetaData::NullPointer();
}


// -----------------------------------------------------------------------------
//
// -----------------------------------------------------------------------------
void ZeissTagMapping::initIdNameMap()
{
  _idNameMap[Zeiss::MetaXML::ImageDataMappingTableId] = Zeiss::MetaXML::ImageDataMappingTable;
  _idNameMap[Zeiss::MetaXML::ImageDataMappingLowId] = Zeiss::MetaXML::ImageDataMappingLow;
  _idNameMap[Zeiss::MetaXML::ImageDataMappingHighId] = Zeiss::MetaXML::ImageDataMappingHigh;
  _idNameMap[Zeiss::MetaXML::ImageDataMappingAutoRangeId] = Zeiss::MetaXML::ImageDataMappingAutoRange;
  _idNameMap[Zeiss::MetaXML::DocumentThumbnailId] = Zeiss::MetaXML::DocumentThumbnail;
  _idNameMap[Zeiss::MetaXML::ImageDataMappingGammaId] = Zeiss::MetaXML::ImageDataMappingGamma;
  _idNameMap[Zeiss::MetaXML::ImageDataHistoMaxId] = Zeiss::MetaXML::ImageDataHistoMax;
  _idNameMap[Zeiss::MetaXML::ImageOverExposureId] = Zeiss::MetaXML::ImageOverExposure;
  _idNameMap[Zeiss::MetaXML::ImageRelativeTimeFirstId] = Zeiss::MetaXML::ImageRelativeTimeFirst;
  _idNameMap[Zeiss::MetaXML::ImageRelativeTime1Id] = Zeiss::MetaXML::ImageRelativeTime1;
  _idNameMap[Zeiss::MetaXML::ImageRelativeTime2Id] = Zeiss::MetaXML::ImageRelativeTime2;
  _idNameMap[Zeiss::MetaXML::ImageRelativeTime3Id] = Zeiss::MetaXML::ImageRelativeTime3;
  _idNameMap[Zeiss::MetaXML::ImageRelativeTime4Id] = Zeiss::MetaXML::ImageRelativeTime4;
  _idNameMap[Zeiss::MetaXML::ImageRelativeTimeId] = Zeiss::MetaXML::ImageRelativeTime;
  _idNameMap[Zeiss::MetaXML::ImageBaseTimeFirstId] = Zeiss::MetaXML::ImageBaseTimeFirst;
  _idNameMap[Zeiss::MetaXML::ImageBaseTime1Id] = Zeiss::MetaXML::ImageBaseTime1;
  _idNameMap[Zeiss::MetaXML::ImageBaseTime2Id] = Zeiss::MetaXML::ImageBaseTime2;
  _idNameMap[Zeiss::MetaXML::ImageBaseTime3Id] = Zeiss::MetaXML::ImageBaseTime3;
  _idNameMap[Zeiss::MetaXML::ImageBaseTime4Id] = Zeiss::MetaXML::ImageBaseTime4;
  _idNameMap[Zeiss::MetaXML::ImageBaseTimeLast_reservedId] = Zeiss::MetaXML::ImageBaseTimeLast_reserved;
  _idNameMap[Zeiss::MetaXML::RelFocusPosition1Id] = Zeiss::MetaXML::RelFocusPosition1;
  _idNameMap[Zeiss::MetaXML::RelFocusPosition2Id] = Zeiss::MetaXML::RelFocusPosition2;
  _idNameMap[Zeiss::MetaXML::ImageObjectTypeId] = Zeiss::MetaXML::ImageObjectType;
  _idNameMap[Zeiss::MetaXML::ImageWidthId] = Zeiss::MetaXML::ImageWidth;
  _idNameMap[Zeiss::MetaXML::ImageHeightId] = Zeiss::MetaXML::ImageHeight;
  _idNameMap[Zeiss::MetaXML::ImageCountRawId] = Zeiss::MetaXML::ImageCountRaw;
  _idNameMap[Zeiss::MetaXML::ImagePixelTypeId] = Zeiss::MetaXML::ImagePixelType;
  _idNameMap[Zeiss::MetaXML::CountId] = Zeiss::MetaXML::Count;
  _idNameMap[Zeiss::MetaXML::CompressionFactorForSaveId] = Zeiss::MetaXML::CompressionFactorForSave;
  _idNameMap[Zeiss::MetaXML::DocumentSaveFlagsId] = Zeiss::MetaXML::DocumentSaveFlags;
  _idNameMap[Zeiss::MetaXML::ImageTimestampCommentsId] = Zeiss::MetaXML::ImageTimestampComments;
  _idNameMap[Zeiss::MetaXML::DocumentSubTypeId] = Zeiss::MetaXML::DocumentSubType;
  _idNameMap[Zeiss::MetaXML::CameraImageValidBitsPerPixelId] = Zeiss::MetaXML::CameraImageValidBitsPerPixel;
  _idNameMap[Zeiss::MetaXML::ImageMemoryUsageId] = Zeiss::MetaXML::ImageMemoryUsage;
  _idNameMap[Zeiss::MetaXML::ImageMSBShiftForPixelsId] = Zeiss::MetaXML::ImageMSBShiftForPixels;
  _idNameMap[Zeiss::MetaXML::ScaleFactorForWidthId] = Zeiss::MetaXML::ScaleFactorForWidth;
  _idNameMap[Zeiss::MetaXML::ScaleTypeForWidthId] = Zeiss::MetaXML::ScaleTypeForWidth;
  _idNameMap[Zeiss::MetaXML::ScaleWidthId] = Zeiss::MetaXML::ScaleWidth;
  _idNameMap[Zeiss::MetaXML::ScaleFactorForHeightId] = Zeiss::MetaXML::ScaleFactorForHeight;
  _idNameMap[Zeiss::MetaXML::ScaleTypeForHeightId] = Zeiss::MetaXML::ScaleTypeForHeight;
  _idNameMap[Zeiss::MetaXML::ScaleHeightId] = Zeiss::MetaXML::ScaleHeight;
  _idNameMap[Zeiss::MetaXML::ScaleFactorForDepthId] = Zeiss::MetaXML::ScaleFactorForDepth;
  _idNameMap[Zeiss::MetaXML::ScaleTypeForDepthId] = Zeiss::MetaXML::ScaleTypeForDepth;
  _idNameMap[Zeiss::MetaXML::ScaleDepthId] = Zeiss::MetaXML::ScaleDepth;
  _idNameMap[Zeiss::MetaXML::ScalingParentId] = Zeiss::MetaXML::ScalingParent;
  _idNameMap[Zeiss::MetaXML::EventLogTypeId] = Zeiss::MetaXML::EventLogType;
  _idNameMap[Zeiss::MetaXML::EventLogDateId] = Zeiss::MetaXML::EventLogDate;
  _idNameMap[Zeiss::MetaXML::EventLogCodeId] = Zeiss::MetaXML::EventLogCode;
  _idNameMap[Zeiss::MetaXML::EventLogSourceNameId] = Zeiss::MetaXML::EventLogSourceName;
  _idNameMap[Zeiss::MetaXML::EventLogMessageId] = Zeiss::MetaXML::EventLogMessage;
  _idNameMap[Zeiss::MetaXML::AcquisitionGroupId] = Zeiss::MetaXML::AcquisitionGroup;
  _idNameMap[Zeiss::MetaXML::CameraImageAcquisitionTimeId] = Zeiss::MetaXML::CameraImageAcquisitionTime;
  _idNameMap[Zeiss::MetaXML::CameraValidBitsPerPixelId] = Zeiss::MetaXML::CameraValidBitsPerPixel;
  _idNameMap[Zeiss::MetaXML::MonoReferenceLowId] = Zeiss::MetaXML::MonoReferenceLow;
  _idNameMap[Zeiss::MetaXML::MonoReferenceHighId] = Zeiss::MetaXML::MonoReferenceHigh;
  _idNameMap[Zeiss::MetaXML::RedReferenceLowId] = Zeiss::MetaXML::RedReferenceLow;
  _idNameMap[Zeiss::MetaXML::RedReferenceHighId] = Zeiss::MetaXML::RedReferenceHigh;
  _idNameMap[Zeiss::MetaXML::GreenReferenceLowId] = Zeiss::MetaXML::GreenReferenceLow;
  _idNameMap[Zeiss::MetaXML::GreenReferenceHighId] = Zeiss::MetaXML::GreenReferenceHigh;
  _idNameMap[Zeiss::MetaXML::BlueReferenceLowId] = Zeiss::MetaXML::BlueReferenceLow;
  _idNameMap[Zeiss::MetaXML::BlueReferenceHighId] = Zeiss::MetaXML::BlueReferenceHigh;
  _idNameMap[Zeiss::MetaXML::GrabberNameId] = Zeiss::MetaXML::GrabberName;
  _idNameMap[Zeiss::MetaXML::CameraNameId] = Zeiss::MetaXML::CameraName;
  _idNameMap[Zeiss::MetaXML::CameraTriggerSignalTypeId] = Zeiss::MetaXML::CameraTriggerSignalType;
  _idNameMap[Zeiss::MetaXML::CameraTriggerEnableId] = Zeiss::MetaXML::CameraTriggerEnable;
  _idNameMap[Zeiss::MetaXML::GrabberTimeoutId] = Zeiss::MetaXML::GrabberTimeout;
  _idNameMap[Zeiss::MetaXML::AcquisitionTimeInDoubleId] = Zeiss::MetaXML::AcquisitionTimeInDouble;
  _idNameMap[Zeiss::MetaXML::MultiChannelEnabledId] = Zeiss::MetaXML::MultiChannelEnabled;
  _idNameMap[Zeiss::MetaXML::MultiChannelColorId] = Zeiss::MetaXML::MultiChannelColor;
  _idNameMap[Zeiss::MetaXML::MultiChannelWeightId] = Zeiss::MetaXML::MultiChannelWeight;
  _idNameMap[Zeiss::MetaXML::MultiChannelNameId] = Zeiss::MetaXML::MultiChannelName;
  _idNameMap[Zeiss::MetaXML::DocumentInformationGroupId] = Zeiss::MetaXML::DocumentInformationGroup;
  _idNameMap[Zeiss::MetaXML::DocumentTitleId] = Zeiss::MetaXML::DocumentTitle;
  _idNameMap[Zeiss::MetaXML::DocumentAuthorId] = Zeiss::MetaXML::DocumentAuthor;
  _idNameMap[Zeiss::MetaXML::DocumentKeywordsId] = Zeiss::MetaXML::DocumentKeywords;
  _idNameMap[Zeiss::MetaXML::DocumentCommentsId] = Zeiss::MetaXML::DocumentComments;
  _idNameMap[Zeiss::MetaXML::DocumentSampleIDId] = Zeiss::MetaXML::DocumentSampleID;
  _idNameMap[Zeiss::MetaXML::DocumentSubjectId] = Zeiss::MetaXML::DocumentSubject;
  _idNameMap[Zeiss::MetaXML::RevisionNumberId] = Zeiss::MetaXML::RevisionNumber;
  _idNameMap[Zeiss::MetaXML::DocumentPathId] = Zeiss::MetaXML::DocumentPath;
  _idNameMap[Zeiss::MetaXML::FileLinkId] = Zeiss::MetaXML::FileLink;
  _idNameMap[Zeiss::MetaXML::DocumentTypeId] = Zeiss::MetaXML::DocumentType;
  _idNameMap[Zeiss::MetaXML::FileMediumId] = Zeiss::MetaXML::FileMedium;
  _idNameMap[Zeiss::MetaXML::FileIDId] = Zeiss::MetaXML::FileID;
  _idNameMap[Zeiss::MetaXML::DocumentFileNameId] = Zeiss::MetaXML::DocumentFileName;
  _idNameMap[Zeiss::MetaXML::FileDateId] = Zeiss::MetaXML::FileDate;
  _idNameMap[Zeiss::MetaXML::FileSizeId] = Zeiss::MetaXML::FileSize;
  _idNameMap[Zeiss::MetaXML::DocumentNameId] = Zeiss::MetaXML::DocumentName;
  _idNameMap[Zeiss::MetaXML::FileAttributesId] = Zeiss::MetaXML::FileAttributes;
  _idNameMap[Zeiss::MetaXML::ProjectGroupId] = Zeiss::MetaXML::ProjectGroup;
  _idNameMap[Zeiss::MetaXML::DateId] = Zeiss::MetaXML::Date;
  _idNameMap[Zeiss::MetaXML::DocumentLastSavedById] = Zeiss::MetaXML::DocumentLastSavedBy;
  _idNameMap[Zeiss::MetaXML::UserCompanyId] = Zeiss::MetaXML::UserCompany;
  _idNameMap[Zeiss::MetaXML::UserCompanyLogoId] = Zeiss::MetaXML::UserCompanyLogo;
  _idNameMap[Zeiss::MetaXML::ImageId] = Zeiss::MetaXML::Image;
  _idNameMap[Zeiss::MetaXML::UserIdId] = Zeiss::MetaXML::UserId;
  _idNameMap[Zeiss::MetaXML::UserNameId] = Zeiss::MetaXML::UserName;
  _idNameMap[Zeiss::MetaXML::UserCityId] = Zeiss::MetaXML::UserCity;
  _idNameMap[Zeiss::MetaXML::UserAddressId] = Zeiss::MetaXML::UserAddress;
  _idNameMap[Zeiss::MetaXML::UserStateId] = Zeiss::MetaXML::UserState;
  _idNameMap[Zeiss::MetaXML::UserPhoneId] = Zeiss::MetaXML::UserPhone;
  _idNameMap[Zeiss::MetaXML::UserFaxId] = Zeiss::MetaXML::UserFax;
  _idNameMap[Zeiss::MetaXML::ObjectiveId] = Zeiss::MetaXML::Objective;
  _idNameMap[Zeiss::MetaXML::OptovarId] = Zeiss::MetaXML::Optovar;
  _idNameMap[Zeiss::MetaXML::ReflectorId] = Zeiss::MetaXML::Reflector;
  _idNameMap[Zeiss::MetaXML::CondenserContrastId] = Zeiss::MetaXML::CondenserContrast;
  _idNameMap[Zeiss::MetaXML::TransmissionFilter1Id] = Zeiss::MetaXML::TransmissionFilter1;
  _idNameMap[Zeiss::MetaXML::TransmittedLightFilter1Id] = Zeiss::MetaXML::TransmittedLightFilter1;
  _idNameMap[Zeiss::MetaXML::TransmissionFilter2Id] = Zeiss::MetaXML::TransmissionFilter2;
  _idNameMap[Zeiss::MetaXML::TransmittedLightFilter2Id] = Zeiss::MetaXML::TransmittedLightFilter2;
  _idNameMap[Zeiss::MetaXML::InternalShutterId] = Zeiss::MetaXML::InternalShutter;
  _idNameMap[Zeiss::MetaXML::ReflectedLightShutterId] = Zeiss::MetaXML::ReflectedLightShutter;
  _idNameMap[Zeiss::MetaXML::CondenserFrontlensId] = Zeiss::MetaXML::CondenserFrontlens;
  _idNameMap[Zeiss::MetaXML::ExcitationFilterId] = Zeiss::MetaXML::ExcitationFilter;
  _idNameMap[Zeiss::MetaXML::TransmittedLightFieldstopId] = Zeiss::MetaXML::TransmittedLightFieldstop;
  _idNameMap[Zeiss::MetaXML::ReflectedLightApertureId] = Zeiss::MetaXML::ReflectedLightAperture;
  _idNameMap[Zeiss::MetaXML::CondenserNAId] = Zeiss::MetaXML::CondenserNA;
  _idNameMap[Zeiss::MetaXML::LightPathId] = Zeiss::MetaXML::LightPath;
  _idNameMap[Zeiss::MetaXML::HalogenLampOnId] = Zeiss::MetaXML::HalogenLampOn;
  _idNameMap[Zeiss::MetaXML::HalogenLampModeId] = Zeiss::MetaXML::HalogenLampMode;
  _idNameMap[Zeiss::MetaXML::HalogenLampVoltageId] = Zeiss::MetaXML::HalogenLampVoltage;
  _idNameMap[Zeiss::MetaXML::FluoLampModeId] = Zeiss::MetaXML::FluoLampMode;
  _idNameMap[Zeiss::MetaXML::FluoLampIntensityId] = Zeiss::MetaXML::FluoLampIntensity;
  _idNameMap[Zeiss::MetaXML::LightmanagerEnabledId] = Zeiss::MetaXML::LightmanagerEnabled;
  _idNameMap[Zeiss::MetaXML::FocusPositionId] = Zeiss::MetaXML::FocusPosition;
  _idNameMap[Zeiss::MetaXML::ImageCoordinateUId] = Zeiss::MetaXML::ImageCoordinateU;
//  _idNameMap[Zeiss::MetaXML::StageXPositionId] = Zeiss::MetaXML::StageXPosition;
  _idNameMap[Zeiss::MetaXML::ImageCoordinateVId] = Zeiss::MetaXML::ImageCoordinateV;
//  _idNameMap[Zeiss::MetaXML::StageYPositionId] = Zeiss::MetaXML::StageYPosition;
  _idNameMap[Zeiss::MetaXML::MicroscopeNameId] = Zeiss::MetaXML::MicroscopeName;
  _idNameMap[Zeiss::MetaXML::ObjectiveMagnificationId] = Zeiss::MetaXML::ObjectiveMagnification;
  _idNameMap[Zeiss::MetaXML::ObjectiveNAId] = Zeiss::MetaXML::ObjectiveNA;
  _idNameMap[Zeiss::MetaXML::MicroscopeIlluminationId] = Zeiss::MetaXML::MicroscopeIllumination;
  _idNameMap[Zeiss::MetaXML::ExtraShutter1Id] = Zeiss::MetaXML::ExtraShutter1;
  _idNameMap[Zeiss::MetaXML::ExtraShutter2Id] = Zeiss::MetaXML::ExtraShutter2;
  _idNameMap[Zeiss::MetaXML::ExtraShutter3Id] = Zeiss::MetaXML::ExtraShutter3;
  _idNameMap[Zeiss::MetaXML::ExtraFilter1Id] = Zeiss::MetaXML::ExtraFilter1;
  _idNameMap[Zeiss::MetaXML::ExtraFilter2Id] = Zeiss::MetaXML::ExtraFilter2;
  _idNameMap[Zeiss::MetaXML::ParfocalCorrectionId] = Zeiss::MetaXML::ParfocalCorrection;
  _idNameMap[Zeiss::MetaXML::ExtraShutter4Id] = Zeiss::MetaXML::ExtraShutter4;
  _idNameMap[Zeiss::MetaXML::ExtraShutter5Id] = Zeiss::MetaXML::ExtraShutter5;
  _idNameMap[Zeiss::MetaXML::ExtraShutter6Id] = Zeiss::MetaXML::ExtraShutter6;
  _idNameMap[Zeiss::MetaXML::ExtraFilter3Id] = Zeiss::MetaXML::ExtraFilter3;
  _idNameMap[Zeiss::MetaXML::ExtraFilter4Id] = Zeiss::MetaXML::ExtraFilter4;
  _idNameMap[Zeiss::MetaXML::ObjectivePositionId] = Zeiss::MetaXML::ObjectivePosition;
  _idNameMap[Zeiss::MetaXML::ObjectiveContrastMethodId] = Zeiss::MetaXML::ObjectiveContrastMethod;
  _idNameMap[Zeiss::MetaXML::ObjectiveImmersionTypeId] = Zeiss::MetaXML::ObjectiveImmersionType;
  _idNameMap[Zeiss::MetaXML::ReflectorPositionId] = Zeiss::MetaXML::ReflectorPosition;
  _idNameMap[Zeiss::MetaXML::TransmissionFilter1PositionId] = Zeiss::MetaXML::TransmissionFilter1Position;
  _idNameMap[Zeiss::MetaXML::TransmittedLightFilter1PositionId] = Zeiss::MetaXML::TransmittedLightFilter1Position;
  _idNameMap[Zeiss::MetaXML::TransmissionFilter2PositionId] = Zeiss::MetaXML::TransmissionFilter2Position;
  _idNameMap[Zeiss::MetaXML::TransmittedLightFilter2PositionId] = Zeiss::MetaXML::TransmittedLightFilter2Position;
  _idNameMap[Zeiss::MetaXML::ExcitationFilterPositionId] = Zeiss::MetaXML::ExcitationFilterPosition;
  _idNameMap[Zeiss::MetaXML::LampMirrorPositionId] = Zeiss::MetaXML::LampMirrorPosition;
  _idNameMap[Zeiss::MetaXML::ExtraFilter1PositionId] = Zeiss::MetaXML::ExtraFilter1Position;
  _idNameMap[Zeiss::MetaXML::ExtraFilter2PositionId] = Zeiss::MetaXML::ExtraFilter2Position;
  _idNameMap[Zeiss::MetaXML::ExtraFilter3PositionId] = Zeiss::MetaXML::ExtraFilter3Position;
  _idNameMap[Zeiss::MetaXML::ExtraFilter4PositionId] = Zeiss::MetaXML::ExtraFilter4Position;
  _idNameMap[Zeiss::MetaXML::LightmanagerModeId] = Zeiss::MetaXML::LightmanagerMode;
  _idNameMap[Zeiss::MetaXML::HalogenLampCalibratedId] = Zeiss::MetaXML::HalogenLampCalibrated;
  _idNameMap[Zeiss::MetaXML::CondenserNAGoSpeedId] = Zeiss::MetaXML::CondenserNAGoSpeed;
  _idNameMap[Zeiss::MetaXML::TransmittedLightFieldstopGoSpeedId] = Zeiss::MetaXML::TransmittedLightFieldstopGoSpeed;
  _idNameMap[Zeiss::MetaXML::OptovarGoSpeedId] = Zeiss::MetaXML::OptovarGoSpeed;
  _idNameMap[Zeiss::MetaXML::FocusCalibratedId] = Zeiss::MetaXML::FocusCalibrated;
  _idNameMap[Zeiss::MetaXML::FocusBasicPositionId] = Zeiss::MetaXML::FocusBasicPosition;
  _idNameMap[Zeiss::MetaXML::FocusPowerId] = Zeiss::MetaXML::FocusPower;
  _idNameMap[Zeiss::MetaXML::FocusBacklashId] = Zeiss::MetaXML::FocusBacklash;
  _idNameMap[Zeiss::MetaXML::FocusMeasurementOriginId] = Zeiss::MetaXML::FocusMeasurementOrigin;
  _idNameMap[Zeiss::MetaXML::FocusMeasurementDistanceId] = Zeiss::MetaXML::FocusMeasurementDistance;
  _idNameMap[Zeiss::MetaXML::FocusSpeedId] = Zeiss::MetaXML::FocusSpeed;
  _idNameMap[Zeiss::MetaXML::FocusGoSpeedId] = Zeiss::MetaXML::FocusGoSpeed;
  _idNameMap[Zeiss::MetaXML::FocusStepDistanceId] = Zeiss::MetaXML::FocusStepDistance;
  _idNameMap[Zeiss::MetaXML::FocusInitPositionId] = Zeiss::MetaXML::FocusInitPosition;
  _idNameMap[Zeiss::MetaXML::StageCalibratedId] = Zeiss::MetaXML::StageCalibrated;
  _idNameMap[Zeiss::MetaXML::StagePowerId] = Zeiss::MetaXML::StagePower;
  _idNameMap[Zeiss::MetaXML::StageXBacklashId] = Zeiss::MetaXML::StageXBacklash;
  _idNameMap[Zeiss::MetaXML::StageYBacklashId] = Zeiss::MetaXML::StageYBacklash;
  _idNameMap[Zeiss::MetaXML::StageXSpeedId] = Zeiss::MetaXML::StageXSpeed;
  _idNameMap[Zeiss::MetaXML::StageYSpeedId] = Zeiss::MetaXML::StageYSpeed;
  _idNameMap[Zeiss::MetaXML::StageSpeedId] = Zeiss::MetaXML::StageSpeed;
  _idNameMap[Zeiss::MetaXML::StageXGoSpeedId] = Zeiss::MetaXML::StageXGoSpeed;
  _idNameMap[Zeiss::MetaXML::StageYGoSpeedId] = Zeiss::MetaXML::StageYGoSpeed;
  _idNameMap[Zeiss::MetaXML::StageXStepDistanceId] = Zeiss::MetaXML::StageXStepDistance;
  _idNameMap[Zeiss::MetaXML::StageYStepDistanceId] = Zeiss::MetaXML::StageYStepDistance;
  _idNameMap[Zeiss::MetaXML::StageXInitPositionId] = Zeiss::MetaXML::StageXInitPosition;
  _idNameMap[Zeiss::MetaXML::StageYInitPositionId] = Zeiss::MetaXML::StageYInitPosition;
  _idNameMap[Zeiss::MetaXML::MicroscopeMagnificationId] = Zeiss::MetaXML::MicroscopeMagnification;
  _idNameMap[Zeiss::MetaXML::ReflectorMagnificationId] = Zeiss::MetaXML::ReflectorMagnification;
  _idNameMap[Zeiss::MetaXML::LampMirrorSelectionId] = Zeiss::MetaXML::LampMirrorSelection;
  _idNameMap[Zeiss::MetaXML::FocusDepthId] = Zeiss::MetaXML::FocusDepth;
  _idNameMap[Zeiss::MetaXML::MicroscopeTypeId] = Zeiss::MetaXML::MicroscopeType;
  _idNameMap[Zeiss::MetaXML::ObjectiveWorkingDistanceId] = Zeiss::MetaXML::ObjectiveWorkingDistance;
  _idNameMap[Zeiss::MetaXML::ReflectedLightApertureGoSpeedId] = Zeiss::MetaXML::ReflectedLightApertureGoSpeed;
  _idNameMap[Zeiss::MetaXML::ExternalShutterId] = Zeiss::MetaXML::ExternalShutter;
  _idNameMap[Zeiss::MetaXML::ObjectiveImmersionStopActiveId] = Zeiss::MetaXML::ObjectiveImmersionStopActive;
  _idNameMap[Zeiss::MetaXML::FocusStartSpeedId] = Zeiss::MetaXML::FocusStartSpeed;
  _idNameMap[Zeiss::MetaXML::FocusAccelerationId] = Zeiss::MetaXML::FocusAcceleration;
  _idNameMap[Zeiss::MetaXML::ReflectedLightFieldstopId] = Zeiss::MetaXML::ReflectedLightFieldstop;
  _idNameMap[Zeiss::MetaXML::ReflectedLightFieldstopGoSpeedId] = Zeiss::MetaXML::ReflectedLightFieldstopGoSpeed;
  _idNameMap[Zeiss::MetaXML::ReflectedLightFilter1Id] = Zeiss::MetaXML::ReflectedLightFilter1;
  _idNameMap[Zeiss::MetaXML::ReflectedLightFilter2Id] = Zeiss::MetaXML::ReflectedLightFilter2;
  _idNameMap[Zeiss::MetaXML::ReflectedLightFilter1PositionId] = Zeiss::MetaXML::ReflectedLightFilter1Position;
  _idNameMap[Zeiss::MetaXML::ReflectedLightFilter2PositionId] = Zeiss::MetaXML::ReflectedLightFilter2Position;
  _idNameMap[Zeiss::MetaXML::TransmittedLightAttenuatorId] = Zeiss::MetaXML::TransmittedLightAttenuator;
  _idNameMap[Zeiss::MetaXML::ReflectedLightAttenuatorId] = Zeiss::MetaXML::ReflectedLightAttenuator;
  _idNameMap[Zeiss::MetaXML::TransmittedLightShutterId] = Zeiss::MetaXML::TransmittedLightShutter;
  _idNameMap[Zeiss::MetaXML::TransmittedLightAttenuatorGoSpeedId] = Zeiss::MetaXML::TransmittedLightAttenuatorGoSpeed;
  _idNameMap[Zeiss::MetaXML::ReflectedLightAttenuatorGoSpeedId] = Zeiss::MetaXML::ReflectedLightAttenuatorGoSpeed;
  _idNameMap[Zeiss::MetaXML::ApotomeFocusPositionId] = Zeiss::MetaXML::ApotomeFocusPosition;
  _idNameMap[Zeiss::MetaXML::ApotomeFocusGoSpeedId] = Zeiss::MetaXML::ApotomeFocusGoSpeed;
  _idNameMap[Zeiss::MetaXML::ApotomePhasePositionId] = Zeiss::MetaXML::ApotomePhasePosition;
  _idNameMap[Zeiss::MetaXML::ApotomeSliderPositionId] = Zeiss::MetaXML::ApotomeSliderPosition;
  _idNameMap[Zeiss::MetaXML::ApotomeGridLinesPerMillimeterId] = Zeiss::MetaXML::ApotomeGridLinesPerMillimeter;
  _idNameMap[Zeiss::MetaXML::ApotomeWobbleMinPositionId] = Zeiss::MetaXML::ApotomeWobbleMinPosition;
  _idNameMap[Zeiss::MetaXML::ApotomeWobbleMaxPositionId] = Zeiss::MetaXML::ApotomeWobbleMaxPosition;
  _idNameMap[Zeiss::MetaXML::ApotomeWobbleSpeedId] = Zeiss::MetaXML::ApotomeWobbleSpeed;
  _idNameMap[Zeiss::MetaXML::TransmittedLightVirtualFilterPositionId] = Zeiss::MetaXML::TransmittedLightVirtualFilterPosition;
  _idNameMap[Zeiss::MetaXML::TransmittedLightVirtualFilterId] = Zeiss::MetaXML::TransmittedLightVirtualFilter;
  _idNameMap[Zeiss::MetaXML::ReflectedLightVirtualFilterPositionId] = Zeiss::MetaXML::ReflectedLightVirtualFilterPosition;
  _idNameMap[Zeiss::MetaXML::ReflectedLightVirtualFilterId] = Zeiss::MetaXML::ReflectedLightVirtualFilter;
  _idNameMap[Zeiss::MetaXML::ReflectedLightHALModeId] = Zeiss::MetaXML::ReflectedLightHALMode;
  _idNameMap[Zeiss::MetaXML::ReflectedLightHALVoltageId] = Zeiss::MetaXML::ReflectedLightHALVoltage;
  _idNameMap[Zeiss::MetaXML::ReflectedLightHALColourTemperatureId] = Zeiss::MetaXML::ReflectedLightHALColourTemperature;
  _idNameMap[Zeiss::MetaXML::ContrastmanagerModeId] = Zeiss::MetaXML::ContrastmanagerMode;
  _idNameMap[Zeiss::MetaXML::DazzleProtectionId] = Zeiss::MetaXML::DazzleProtection;
  _idNameMap[Zeiss::MetaXML::StageXCalibratedId] = Zeiss::MetaXML::StageXCalibrated;
  _idNameMap[Zeiss::MetaXML::StageYCalibratedId] = Zeiss::MetaXML::StageYCalibrated;
  _idNameMap[Zeiss::MetaXML::StageXPowerId] = Zeiss::MetaXML::StageXPower;
  _idNameMap[Zeiss::MetaXML::StageYPowerId] = Zeiss::MetaXML::StageYPower;
  _idNameMap[Zeiss::MetaXML::StageXStartSpeedId] = Zeiss::MetaXML::StageXStartSpeed;
  _idNameMap[Zeiss::MetaXML::StageYStartSpeedId] = Zeiss::MetaXML::StageYStartSpeed;
  _idNameMap[Zeiss::MetaXML::StageXAccelerationId] = Zeiss::MetaXML::StageXAcceleration;
  _idNameMap[Zeiss::MetaXML::StageYAccelerationId] = Zeiss::MetaXML::StageYAcceleration;
  _idNameMap[Zeiss::MetaXML::StageStartSpeedId] = Zeiss::MetaXML::StageStartSpeed;
  _idNameMap[Zeiss::MetaXML::StageAccelerationId] = Zeiss::MetaXML::StageAcceleration;
  _idNameMap[Zeiss::MetaXML::ZoomId] = Zeiss::MetaXML::Zoom;
  _idNameMap[Zeiss::MetaXML::ZoomGoSpeedId] = Zeiss::MetaXML::ZoomGoSpeed;
  _idNameMap[Zeiss::MetaXML::LightZoomId] = Zeiss::MetaXML::LightZoom;
  _idNameMap[Zeiss::MetaXML::LightZoomGoSpeedId] = Zeiss::MetaXML::LightZoomGoSpeed;
  _idNameMap[Zeiss::MetaXML::LightZoomCoupledId] = Zeiss::MetaXML::LightZoomCoupled;
  _idNameMap[Zeiss::MetaXML::TransmittedLightHALModeId] = Zeiss::MetaXML::TransmittedLightHALMode;
  _idNameMap[Zeiss::MetaXML::TransmittedLightHALVoltageId] = Zeiss::MetaXML::TransmittedLightHALVoltage;
  _idNameMap[Zeiss::MetaXML::TransmittedLightHALColourTemperatureId] = Zeiss::MetaXML::TransmittedLightHALColourTemperature;
  _idNameMap[Zeiss::MetaXML::ReflectedLightCLModeId] = Zeiss::MetaXML::ReflectedLightCLMode;
  _idNameMap[Zeiss::MetaXML::ReflectedLightCLIntensityId] = Zeiss::MetaXML::ReflectedLightCLIntensity;
  _idNameMap[Zeiss::MetaXML::ReflectedLightCLColourTemperatureId] = Zeiss::MetaXML::ReflectedLightCLColourTemperature;
  _idNameMap[Zeiss::MetaXML::TransmittedLightCLModeId] = Zeiss::MetaXML::TransmittedLightCLMode;
  _idNameMap[Zeiss::MetaXML::TransmittedLightCLIntensityId] = Zeiss::MetaXML::TransmittedLightCLIntensity;
  _idNameMap[Zeiss::MetaXML::TransmittedLightCLColourTemperatureId] = Zeiss::MetaXML::TransmittedLightCLColourTemperature;
  _idNameMap[Zeiss::MetaXML::InfinitySpaceChangerPositionId] = Zeiss::MetaXML::InfinitySpaceChangerPosition;
  _idNameMap[Zeiss::MetaXML::SidePortPercentId] = Zeiss::MetaXML::SidePortPercent;
  _idNameMap[Zeiss::MetaXML::TwoTvVisCamChangerPositionId] = Zeiss::MetaXML::TwoTvVisCamChangerPosition;
  _idNameMap[Zeiss::MetaXML::OcularPercentId] = Zeiss::MetaXML::OcularPercent;
  _idNameMap[Zeiss::MetaXML::TwoTvCamerasChangerPositionId] = Zeiss::MetaXML::TwoTvCamerasChangerPosition;
  _idNameMap[Zeiss::MetaXML::TopPortPercentId] = Zeiss::MetaXML::TopPortPercent;
  _idNameMap[Zeiss::MetaXML::OcularShutterId] = Zeiss::MetaXML::OcularShutter;
  _idNameMap[Zeiss::MetaXML::TwoTvCamerasChangerCubeId] = Zeiss::MetaXML::TwoTvCamerasChangerCube;
  _idNameMap[Zeiss::MetaXML::LightWaveLengthId] = Zeiss::MetaXML::LightWaveLength;
  _idNameMap[Zeiss::MetaXML::OcularMagnificationId] = Zeiss::MetaXML::OcularMagnification;
  _idNameMap[Zeiss::MetaXML::CameraAdapterMagnificationId] = Zeiss::MetaXML::CameraAdapterMagnification;
  _idNameMap[Zeiss::MetaXML::MicroscopePortId] = Zeiss::MetaXML::MicroscopePort;
  _idNameMap[Zeiss::MetaXML::OcularTotalMagnificationId] = Zeiss::MetaXML::OcularTotalMagnification;
  _idNameMap[Zeiss::MetaXML::FieldOfViewId] = Zeiss::MetaXML::FieldOfView;
  _idNameMap[Zeiss::MetaXML::OcularId] = Zeiss::MetaXML::Ocular;
  _idNameMap[Zeiss::MetaXML::CameraAdapterId] = Zeiss::MetaXML::CameraAdapter;
  _idNameMap[Zeiss::MetaXML::StageJoystickEnabledId] = Zeiss::MetaXML::StageJoystickEnabled;
  _idNameMap[Zeiss::MetaXML::ContrastmanagerContrastMethodId] = Zeiss::MetaXML::ContrastmanagerContrastMethod;
  _idNameMap[Zeiss::MetaXML::StageXJoystickEnabledId] = Zeiss::MetaXML::StageXJoystickEnabled;
  _idNameMap[Zeiss::MetaXML::StageYJoystickEnabledId] = Zeiss::MetaXML::StageYJoystickEnabled;
  _idNameMap[Zeiss::MetaXML::CameraFrameLeftId] = Zeiss::MetaXML::CameraFrameLeft;
  _idNameMap[Zeiss::MetaXML::CameraFrameTopId] = Zeiss::MetaXML::CameraFrameTop;
  _idNameMap[Zeiss::MetaXML::CameraFrameWidthId] = Zeiss::MetaXML::CameraFrameWidth;
  _idNameMap[Zeiss::MetaXML::CameraFrameHeightId] = Zeiss::MetaXML::CameraFrameHeight;
  _idNameMap[Zeiss::MetaXML::CameraFrameBinningId] = Zeiss::MetaXML::CameraFrameBinning;
  _idNameMap[Zeiss::MetaXML::CameraFrameFullId] = Zeiss::MetaXML::CameraFrameFull;
  _idNameMap[Zeiss::MetaXML::CameraFramePixelDistanceId] = Zeiss::MetaXML::CameraFramePixelDistance;
  _idNameMap[Zeiss::MetaXML::DataFormatUseScalingId] = Zeiss::MetaXML::DataFormatUseScaling;
  _idNameMap[Zeiss::MetaXML::CameraFrameImageOrientationId] = Zeiss::MetaXML::CameraFrameImageOrientation;
  _idNameMap[Zeiss::MetaXML::MeteorChannelInputId] = Zeiss::MetaXML::MeteorChannelInput;
  _idNameMap[Zeiss::MetaXML::MeteorChannelSyncId] = Zeiss::MetaXML::MeteorChannelSync;
  _idNameMap[Zeiss::MetaXML::CameraWhiteBalanceRedId] = Zeiss::MetaXML::CameraWhiteBalanceRed;
  _idNameMap[Zeiss::MetaXML::CameraWhiteBalanceGreenId] = Zeiss::MetaXML::CameraWhiteBalanceGreen;
  _idNameMap[Zeiss::MetaXML::CameraWhiteBalanceBlueId] = Zeiss::MetaXML::CameraWhiteBalanceBlue;
  _idNameMap[Zeiss::MetaXML::CameraFrameScalingFactorId] = Zeiss::MetaXML::CameraFrameScalingFactor;
  _idNameMap[Zeiss::MetaXML::MeteorCameraTypeId] = Zeiss::MetaXML::MeteorCameraType;
  _idNameMap[Zeiss::MetaXML::CameraExposureTimeValueId] = Zeiss::MetaXML::CameraExposureTimeValue;
  _idNameMap[Zeiss::MetaXML::CameraExposureTimeAutoCalculateId] = Zeiss::MetaXML::CameraExposureTimeAutoCalculate;
  _idNameMap[Zeiss::MetaXML::MeteorGainValueId] = Zeiss::MetaXML::MeteorGainValue;
  _idNameMap[Zeiss::MetaXML::MeteorGainAutomaticId] = Zeiss::MetaXML::MeteorGainAutomatic;
  _idNameMap[Zeiss::MetaXML::MeteorAdjustHueId] = Zeiss::MetaXML::MeteorAdjustHue;
  _idNameMap[Zeiss::MetaXML::MeteorAdjustSaturationId] = Zeiss::MetaXML::MeteorAdjustSaturation;
  _idNameMap[Zeiss::MetaXML::MeteorAdjustRedLowId] = Zeiss::MetaXML::MeteorAdjustRedLow;
  _idNameMap[Zeiss::MetaXML::MeteorAdjustGreenLowId] = Zeiss::MetaXML::MeteorAdjustGreenLow;
  _idNameMap[Zeiss::MetaXML::MeteorAdjustBlueLowId] = Zeiss::MetaXML::MeteorAdjustBlueLow;
  _idNameMap[Zeiss::MetaXML::MeteorAdjustRedHighId] = Zeiss::MetaXML::MeteorAdjustRedHigh;
  _idNameMap[Zeiss::MetaXML::MeteorAdjustGreenHighId] = Zeiss::MetaXML::MeteorAdjustGreenHigh;
  _idNameMap[Zeiss::MetaXML::MeteorAdjustBlueHighId] = Zeiss::MetaXML::MeteorAdjustBlueHigh;
  _idNameMap[Zeiss::MetaXML::MeteorAdjustWhiteRefEnableId] = Zeiss::MetaXML::MeteorAdjustWhiteRefEnable;
  _idNameMap[Zeiss::MetaXML::CameraExposureTimeCalculationControlId] = Zeiss::MetaXML::CameraExposureTimeCalculationControl;
  _idNameMap[Zeiss::MetaXML::AxioCamFadingCorrectionEnableId] = Zeiss::MetaXML::AxioCamFadingCorrectionEnable;
  _idNameMap[Zeiss::MetaXML::AxioCamSuspendLiveTimeoutId] = Zeiss::MetaXML::AxioCamSuspendLiveTimeout;
  _idNameMap[Zeiss::MetaXML::CameraLiveImageId] = Zeiss::MetaXML::CameraLiveImage;
  _idNameMap[Zeiss::MetaXML::CameraLiveEnabledId] = Zeiss::MetaXML::CameraLiveEnabled;
  _idNameMap[Zeiss::MetaXML::LiveImageSyncObjectNameId] = Zeiss::MetaXML::LiveImageSyncObjectName;
  _idNameMap[Zeiss::MetaXML::CameraLiveSpeedId] = Zeiss::MetaXML::CameraLiveSpeed;
  _idNameMap[Zeiss::MetaXML::CameraImageId] = Zeiss::MetaXML::CameraImage;
  _idNameMap[Zeiss::MetaXML::CameraImageWidthId] = Zeiss::MetaXML::CameraImageWidth;
  _idNameMap[Zeiss::MetaXML::CameraImageHeightId] = Zeiss::MetaXML::CameraImageHeight;
  _idNameMap[Zeiss::MetaXML::CameraImagePixelTypeId] = Zeiss::MetaXML::CameraImagePixelType;
  _idNameMap[Zeiss::MetaXML::CameraImageShMemoryNameId] = Zeiss::MetaXML::CameraImageShMemoryName;
  _idNameMap[Zeiss::MetaXML::CameraLiveImageWidthId] = Zeiss::MetaXML::CameraLiveImageWidth;
  _idNameMap[Zeiss::MetaXML::CameraLiveImageHeightId] = Zeiss::MetaXML::CameraLiveImageHeight;
  _idNameMap[Zeiss::MetaXML::CameraLiveImagePixelTypeId] = Zeiss::MetaXML::CameraLiveImagePixelType;
  _idNameMap[Zeiss::MetaXML::CameraLiveImageShMemoryNameId] = Zeiss::MetaXML::CameraLiveImageShMemoryName;
  _idNameMap[Zeiss::MetaXML::CameraLiveMaximumSpeedId] = Zeiss::MetaXML::CameraLiveMaximumSpeed;
  _idNameMap[Zeiss::MetaXML::CameraLiveBinningId] = Zeiss::MetaXML::CameraLiveBinning;
  _idNameMap[Zeiss::MetaXML::CameraLiveGainValueId] = Zeiss::MetaXML::CameraLiveGainValue;
  _idNameMap[Zeiss::MetaXML::CameraLiveExposureTimeValueId] = Zeiss::MetaXML::CameraLiveExposureTimeValue;
  _idNameMap[Zeiss::MetaXML::CameraLiveScalingFactorId] = Zeiss::MetaXML::CameraLiveScalingFactor;
  _idNameMap[Zeiss::MetaXML::CameraCoAcqFastModeId] = Zeiss::MetaXML::CameraCoAcqFastMode;
  _idNameMap[Zeiss::MetaXML::ImageIndexUId] = Zeiss::MetaXML::ImageIndexU;
  _idNameMap[Zeiss::MetaXML::ImageIndexVId] = Zeiss::MetaXML::ImageIndexV;
  _idNameMap[Zeiss::MetaXML::ImageIndexZId] = Zeiss::MetaXML::ImageIndexZ;
  _idNameMap[Zeiss::MetaXML::ImageIndexCId] = Zeiss::MetaXML::ImageIndexC;
  _idNameMap[Zeiss::MetaXML::ImageIndexTId] = Zeiss::MetaXML::ImageIndexT;
  _idNameMap[Zeiss::MetaXML::ImageIndexPId] = Zeiss::MetaXML::ImageIndexP;
  _idNameMap[Zeiss::MetaXML::ImageIndexAId] = Zeiss::MetaXML::ImageIndexA;
  _idNameMap[Zeiss::MetaXML::ImageCountPId] = Zeiss::MetaXML::ImageCountP;
  _idNameMap[Zeiss::MetaXML::ImageCountAId] = Zeiss::MetaXML::ImageCountA;
  _idNameMap[Zeiss::MetaXML::ImageIndexSId] = Zeiss::MetaXML::ImageIndexS;
  _idNameMap[Zeiss::MetaXML::ImageIndexRawId] = Zeiss::MetaXML::ImageIndexRaw;
  _idNameMap[Zeiss::MetaXML::ImageCountZId] = Zeiss::MetaXML::ImageCountZ;
  _idNameMap[Zeiss::MetaXML::ImageCountCId] = Zeiss::MetaXML::ImageCountC;
  _idNameMap[Zeiss::MetaXML::ImageCountTId] = Zeiss::MetaXML::ImageCountT;
  _idNameMap[Zeiss::MetaXML::ImageCountUId] = Zeiss::MetaXML::ImageCountU;
  _idNameMap[Zeiss::MetaXML::ImageCountVId] = Zeiss::MetaXML::ImageCountV;
  _idNameMap[Zeiss::MetaXML::ImageCountSId] = Zeiss::MetaXML::ImageCountS;
  _idNameMap[Zeiss::MetaXML::ImageOrgCoordinateUId] = Zeiss::MetaXML::ImageOrgCoordinateU;
  _idNameMap[Zeiss::MetaXML::ImageOrgCoordinateVId] = Zeiss::MetaXML::ImageOrgCoordinateV;
  _idNameMap[Zeiss::MetaXML::LayerDrawFlagsId] = Zeiss::MetaXML::LayerDrawFlags;
  _idNameMap[Zeiss::MetaXML::JobGroupId] = Zeiss::MetaXML::JobGroup;
  _idNameMap[Zeiss::MetaXML::JobNameId] = Zeiss::MetaXML::JobName;
  _idNameMap[Zeiss::MetaXML::JobInfoId] = Zeiss::MetaXML::JobInfo;
  _idNameMap[Zeiss::MetaXML::JobProgressId] = Zeiss::MetaXML::JobProgress;
  _idNameMap[Zeiss::MetaXML::JobStatusId] = Zeiss::MetaXML::JobStatus;
  _idNameMap[Zeiss::MetaXML::JobIdId] = Zeiss::MetaXML::JobId;
  _idNameMap[Zeiss::MetaXML::JobRemainingTimeId] = Zeiss::MetaXML::JobRemainingTime;
  _idNameMap[Zeiss::MetaXML::AcquisitionTimeInDoubleId] = Zeiss::MetaXML::AcquisitionTimeInDouble;
  _idNameMap[Zeiss::MetaXML::RelFocusPositionId] = Zeiss::MetaXML::RelFocusPosition;
  _idNameMap[Zeiss::MetaXML::SidePortTurretpositionId] = Zeiss::MetaXML::SidePortTurretposition;
  _idNameMap[Zeiss::MetaXML::SidePortLeftPercentId] = Zeiss::MetaXML::SidePortLeftPercent;
  _idNameMap[Zeiss::MetaXML::SidePortRightPercentId] = Zeiss::MetaXML::SidePortRightPercent;
  _idNameMap[Zeiss::MetaXML::BasePortSliderPortPercentId] = Zeiss::MetaXML::BasePortSliderPortPercent;
  _idNameMap[Zeiss::MetaXML::SidePortLeftFunctionId] = Zeiss::MetaXML::SidePortLeftFunction;
  _idNameMap[Zeiss::MetaXML::SidePortRightFunctionId] = Zeiss::MetaXML::SidePortRightFunction;
  _idNameMap[Zeiss::MetaXML::BasePortSliderPortFunctionId] = Zeiss::MetaXML::BasePortSliderPortFunction;
  _idNameMap[Zeiss::MetaXML::SidePortLightPathId] = Zeiss::MetaXML::SidePortLightPath;
  _idNameMap[Zeiss::MetaXML::SidePortLightPathIDId] = Zeiss::MetaXML::SidePortLightPathID;
  _idNameMap[Zeiss::MetaXML::ObjectiveIDId] = Zeiss::MetaXML::ObjectiveID;
  _idNameMap[Zeiss::MetaXML::ReflectorIDId] = Zeiss::MetaXML::ReflectorID;
}
//------------------------------------------------------------------------------
void ZeissTagMapping::initNameIdMap()
{
_nameIdMap[Zeiss::MetaXML::ImageDataMappingTable] = Zeiss::MetaXML::ImageDataMappingTableId;
_nameIdMap[Zeiss::MetaXML::ImageDataMappingLow] = Zeiss::MetaXML::ImageDataMappingLowId;
_nameIdMap[Zeiss::MetaXML::ImageDataMappingHigh] = Zeiss::MetaXML::ImageDataMappingHighId;
_nameIdMap[Zeiss::MetaXML::ImageDataMappingAutoRange] = Zeiss::MetaXML::ImageDataMappingAutoRangeId;
_nameIdMap[Zeiss::MetaXML::DocumentThumbnail] = Zeiss::MetaXML::DocumentThumbnailId;
_nameIdMap[Zeiss::MetaXML::ImageDataMappingGamma] = Zeiss::MetaXML::ImageDataMappingGammaId;
_nameIdMap[Zeiss::MetaXML::ImageDataHistoMax] = Zeiss::MetaXML::ImageDataHistoMaxId;
_nameIdMap[Zeiss::MetaXML::ImageOverExposure] = Zeiss::MetaXML::ImageOverExposureId;
_nameIdMap[Zeiss::MetaXML::ImageRelativeTimeFirst] = Zeiss::MetaXML::ImageRelativeTimeFirstId;
_nameIdMap[Zeiss::MetaXML::ImageRelativeTime1] = Zeiss::MetaXML::ImageRelativeTime1Id;
_nameIdMap[Zeiss::MetaXML::ImageRelativeTime2] = Zeiss::MetaXML::ImageRelativeTime2Id;
_nameIdMap[Zeiss::MetaXML::ImageRelativeTime3] = Zeiss::MetaXML::ImageRelativeTime3Id;
_nameIdMap[Zeiss::MetaXML::ImageRelativeTime4] = Zeiss::MetaXML::ImageRelativeTime4Id;
_nameIdMap[Zeiss::MetaXML::ImageRelativeTime] = Zeiss::MetaXML::ImageRelativeTimeId;
_nameIdMap[Zeiss::MetaXML::ImageBaseTimeFirst] = Zeiss::MetaXML::ImageBaseTimeFirstId;
_nameIdMap[Zeiss::MetaXML::ImageBaseTime1] = Zeiss::MetaXML::ImageBaseTime1Id;
_nameIdMap[Zeiss::MetaXML::ImageBaseTime2] = Zeiss::MetaXML::ImageBaseTime2Id;
_nameIdMap[Zeiss::MetaXML::ImageBaseTime3] = Zeiss::MetaXML::ImageBaseTime3Id;
_nameIdMap[Zeiss::MetaXML::ImageBaseTime4] = Zeiss::MetaXML::ImageBaseTime4Id;
_nameIdMap[Zeiss::MetaXML::ImageBaseTimeLast_reserved] = Zeiss::MetaXML::ImageBaseTimeLast_reservedId;
_nameIdMap[Zeiss::MetaXML::RelFocusPosition1] = Zeiss::MetaXML::RelFocusPosition1Id;
_nameIdMap[Zeiss::MetaXML::RelFocusPosition2] = Zeiss::MetaXML::RelFocusPosition2Id;
_nameIdMap[Zeiss::MetaXML::ImageObjectType] = Zeiss::MetaXML::ImageObjectTypeId;
_nameIdMap[Zeiss::MetaXML::ImageWidth] = Zeiss::MetaXML::ImageWidthId;
_nameIdMap[Zeiss::MetaXML::ImageHeight] = Zeiss::MetaXML::ImageHeightId;
_nameIdMap[Zeiss::MetaXML::ImageCountRaw] = Zeiss::MetaXML::ImageCountRawId;
_nameIdMap[Zeiss::MetaXML::ImagePixelType] = Zeiss::MetaXML::ImagePixelTypeId;
_nameIdMap[Zeiss::MetaXML::Count] = Zeiss::MetaXML::CountId;
_nameIdMap[Zeiss::MetaXML::CompressionFactorForSave] = Zeiss::MetaXML::CompressionFactorForSaveId;
_nameIdMap[Zeiss::MetaXML::DocumentSaveFlags] = Zeiss::MetaXML::DocumentSaveFlagsId;
_nameIdMap[Zeiss::MetaXML::ImageTimestampComments] = Zeiss::MetaXML::ImageTimestampCommentsId;
_nameIdMap[Zeiss::MetaXML::DocumentSubType] = Zeiss::MetaXML::DocumentSubTypeId;
_nameIdMap[Zeiss::MetaXML::CameraImageValidBitsPerPixel] = Zeiss::MetaXML::CameraImageValidBitsPerPixelId;
_nameIdMap[Zeiss::MetaXML::ImageMemoryUsage] = Zeiss::MetaXML::ImageMemoryUsageId;
_nameIdMap[Zeiss::MetaXML::ImageMSBShiftForPixels] = Zeiss::MetaXML::ImageMSBShiftForPixelsId;
_nameIdMap[Zeiss::MetaXML::ScaleFactorForWidth] = Zeiss::MetaXML::ScaleFactorForWidthId;
_nameIdMap[Zeiss::MetaXML::ScaleTypeForWidth] = Zeiss::MetaXML::ScaleTypeForWidthId;
_nameIdMap[Zeiss::MetaXML::ScaleWidth] = Zeiss::MetaXML::ScaleWidthId;
_nameIdMap[Zeiss::MetaXML::ScaleFactorForHeight] = Zeiss::MetaXML::ScaleFactorForHeightId;
_nameIdMap[Zeiss::MetaXML::ScaleTypeForHeight] = Zeiss::MetaXML::ScaleTypeForHeightId;
_nameIdMap[Zeiss::MetaXML::ScaleHeight] = Zeiss::MetaXML::ScaleHeightId;
_nameIdMap[Zeiss::MetaXML::ScaleFactorForDepth] = Zeiss::MetaXML::ScaleFactorForDepthId;
_nameIdMap[Zeiss::MetaXML::ScaleTypeForDepth] = Zeiss::MetaXML::ScaleTypeForDepthId;
_nameIdMap[Zeiss::MetaXML::ScaleDepth] = Zeiss::MetaXML::ScaleDepthId;
_nameIdMap[Zeiss::MetaXML::ScalingParent] = Zeiss::MetaXML::ScalingParentId;
_nameIdMap[Zeiss::MetaXML::EventLogType] = Zeiss::MetaXML::EventLogTypeId;
_nameIdMap[Zeiss::MetaXML::EventLogDate] = Zeiss::MetaXML::EventLogDateId;
_nameIdMap[Zeiss::MetaXML::EventLogCode] = Zeiss::MetaXML::EventLogCodeId;
_nameIdMap[Zeiss::MetaXML::EventLogSourceName] = Zeiss::MetaXML::EventLogSourceNameId;
_nameIdMap[Zeiss::MetaXML::EventLogMessage] = Zeiss::MetaXML::EventLogMessageId;
_nameIdMap[Zeiss::MetaXML::AcquisitionGroup] = Zeiss::MetaXML::AcquisitionGroupId;
_nameIdMap[Zeiss::MetaXML::CameraImageAcquisitionTime] = Zeiss::MetaXML::CameraImageAcquisitionTimeId;
_nameIdMap[Zeiss::MetaXML::CameraValidBitsPerPixel] = Zeiss::MetaXML::CameraValidBitsPerPixelId;
_nameIdMap[Zeiss::MetaXML::MonoReferenceLow] = Zeiss::MetaXML::MonoReferenceLowId;
_nameIdMap[Zeiss::MetaXML::MonoReferenceHigh] = Zeiss::MetaXML::MonoReferenceHighId;
_nameIdMap[Zeiss::MetaXML::RedReferenceLow] = Zeiss::MetaXML::RedReferenceLowId;
_nameIdMap[Zeiss::MetaXML::RedReferenceHigh] = Zeiss::MetaXML::RedReferenceHighId;
_nameIdMap[Zeiss::MetaXML::GreenReferenceLow] = Zeiss::MetaXML::GreenReferenceLowId;
_nameIdMap[Zeiss::MetaXML::GreenReferenceHigh] = Zeiss::MetaXML::GreenReferenceHighId;
_nameIdMap[Zeiss::MetaXML::BlueReferenceLow] = Zeiss::MetaXML::BlueReferenceLowId;
_nameIdMap[Zeiss::MetaXML::BlueReferenceHigh] = Zeiss::MetaXML::BlueReferenceHighId;
_nameIdMap[Zeiss::MetaXML::GrabberName] = Zeiss::MetaXML::GrabberNameId;
_nameIdMap[Zeiss::MetaXML::CameraName] = Zeiss::MetaXML::CameraNameId;
_nameIdMap[Zeiss::MetaXML::CameraTriggerSignalType] = Zeiss::MetaXML::CameraTriggerSignalTypeId;
_nameIdMap[Zeiss::MetaXML::CameraTriggerEnable] = Zeiss::MetaXML::CameraTriggerEnableId;
_nameIdMap[Zeiss::MetaXML::GrabberTimeout] = Zeiss::MetaXML::GrabberTimeoutId;
_nameIdMap[Zeiss::MetaXML::AcquisitionTimeInDouble] = Zeiss::MetaXML::AcquisitionTimeInDoubleId;
_nameIdMap[Zeiss::MetaXML::MultiChannelEnabled] = Zeiss::MetaXML::MultiChannelEnabledId;
_nameIdMap[Zeiss::MetaXML::MultiChannelColor] = Zeiss::MetaXML::MultiChannelColorId;
_nameIdMap[Zeiss::MetaXML::MultiChannelWeight] = Zeiss::MetaXML::MultiChannelWeightId;
_nameIdMap[Zeiss::MetaXML::MultiChannelName] = Zeiss::MetaXML::MultiChannelNameId;
_nameIdMap[Zeiss::MetaXML::DocumentInformationGroup] = Zeiss::MetaXML::DocumentInformationGroupId;
_nameIdMap[Zeiss::MetaXML::DocumentTitle] = Zeiss::MetaXML::DocumentTitleId;
_nameIdMap[Zeiss::MetaXML::DocumentAuthor] = Zeiss::MetaXML::DocumentAuthorId;
_nameIdMap[Zeiss::MetaXML::DocumentKeywords] = Zeiss::MetaXML::DocumentKeywordsId;
_nameIdMap[Zeiss::MetaXML::DocumentComments] = Zeiss::MetaXML::DocumentCommentsId;
_nameIdMap[Zeiss::MetaXML::DocumentSampleID] = Zeiss::MetaXML::DocumentSampleIDId;
_nameIdMap[Zeiss::MetaXML::DocumentSubject] = Zeiss::MetaXML::DocumentSubjectId;
_nameIdMap[Zeiss::MetaXML::RevisionNumber] = Zeiss::MetaXML::RevisionNumberId;
_nameIdMap[Zeiss::MetaXML::DocumentPath] = Zeiss::MetaXML::DocumentPathId;
_nameIdMap[Zeiss::MetaXML::FileLink] = Zeiss::MetaXML::FileLinkId;
_nameIdMap[Zeiss::MetaXML::DocumentType] = Zeiss::MetaXML::DocumentTypeId;
_nameIdMap[Zeiss::MetaXML::FileMedium] = Zeiss::MetaXML::FileMediumId;
_nameIdMap[Zeiss::MetaXML::FileID] = Zeiss::MetaXML::FileIDId;
_nameIdMap[Zeiss::MetaXML::DocumentFileName] = Zeiss::MetaXML::DocumentFileNameId;
_nameIdMap[Zeiss::MetaXML::FileDate] = Zeiss::MetaXML::FileDateId;
_nameIdMap[Zeiss::MetaXML::FileSize] = Zeiss::MetaXML::FileSizeId;
_nameIdMap[Zeiss::MetaXML::DocumentName] = Zeiss::MetaXML::DocumentNameId;
_nameIdMap[Zeiss::MetaXML::FileAttributes] = Zeiss::MetaXML::FileAttributesId;
_nameIdMap[Zeiss::MetaXML::ProjectGroup] = Zeiss::MetaXML::ProjectGroupId;
_nameIdMap[Zeiss::MetaXML::Date] = Zeiss::MetaXML::DateId;
_nameIdMap[Zeiss::MetaXML::DocumentLastSavedBy] = Zeiss::MetaXML::DocumentLastSavedById;
_nameIdMap[Zeiss::MetaXML::UserCompany] = Zeiss::MetaXML::UserCompanyId;
_nameIdMap[Zeiss::MetaXML::UserCompanyLogo] = Zeiss::MetaXML::UserCompanyLogoId;
_nameIdMap[Zeiss::MetaXML::Image] = Zeiss::MetaXML::ImageId;
_nameIdMap[Zeiss::MetaXML::UserId] = Zeiss::MetaXML::UserIdId;
_nameIdMap[Zeiss::MetaXML::UserName] = Zeiss::MetaXML::UserNameId;
_nameIdMap[Zeiss::MetaXML::UserCity] = Zeiss::MetaXML::UserCityId;
_nameIdMap[Zeiss::MetaXML::UserAddress] = Zeiss::MetaXML::UserAddressId;
_nameIdMap[Zeiss::MetaXML::UserState] = Zeiss::MetaXML::UserStateId;
_nameIdMap[Zeiss::MetaXML::UserPhone] = Zeiss::MetaXML::UserPhoneId;
_nameIdMap[Zeiss::MetaXML::UserFax] = Zeiss::MetaXML::UserFaxId;
_nameIdMap[Zeiss::MetaXML::Objective] = Zeiss::MetaXML::ObjectiveId;
_nameIdMap[Zeiss::MetaXML::Optovar] = Zeiss::MetaXML::OptovarId;
_nameIdMap[Zeiss::MetaXML::Reflector] = Zeiss::MetaXML::ReflectorId;
_nameIdMap[Zeiss::MetaXML::CondenserContrast] = Zeiss::MetaXML::CondenserContrastId;
_nameIdMap[Zeiss::MetaXML::TransmissionFilter1] = Zeiss::MetaXML::TransmissionFilter1Id;
_nameIdMap[Zeiss::MetaXML::TransmittedLightFilter1] = Zeiss::MetaXML::TransmittedLightFilter1Id;
_nameIdMap[Zeiss::MetaXML::TransmissionFilter2] = Zeiss::MetaXML::TransmissionFilter2Id;
_nameIdMap[Zeiss::MetaXML::TransmittedLightFilter2] = Zeiss::MetaXML::TransmittedLightFilter2Id;
_nameIdMap[Zeiss::MetaXML::InternalShutter] = Zeiss::MetaXML::InternalShutterId;
_nameIdMap[Zeiss::MetaXML::ReflectedLightShutter] = Zeiss::MetaXML::ReflectedLightShutterId;
_nameIdMap[Zeiss::MetaXML::CondenserFrontlens] = Zeiss::MetaXML::CondenserFrontlensId;
_nameIdMap[Zeiss::MetaXML::ExcitationFilter] = Zeiss::MetaXML::ExcitationFilterId;
_nameIdMap[Zeiss::MetaXML::TransmittedLightFieldstop] = Zeiss::MetaXML::TransmittedLightFieldstopId;
_nameIdMap[Zeiss::MetaXML::ReflectedLightAperture] = Zeiss::MetaXML::ReflectedLightApertureId;
_nameIdMap[Zeiss::MetaXML::CondenserNA] = Zeiss::MetaXML::CondenserNAId;
_nameIdMap[Zeiss::MetaXML::LightPath] = Zeiss::MetaXML::LightPathId;
_nameIdMap[Zeiss::MetaXML::HalogenLampOn] = Zeiss::MetaXML::HalogenLampOnId;
_nameIdMap[Zeiss::MetaXML::HalogenLampMode] = Zeiss::MetaXML::HalogenLampModeId;
_nameIdMap[Zeiss::MetaXML::HalogenLampVoltage] = Zeiss::MetaXML::HalogenLampVoltageId;
_nameIdMap[Zeiss::MetaXML::FluoLampMode] = Zeiss::MetaXML::FluoLampModeId;
_nameIdMap[Zeiss::MetaXML::FluoLampIntensity] = Zeiss::MetaXML::FluoLampIntensityId;
_nameIdMap[Zeiss::MetaXML::LightmanagerEnabled] = Zeiss::MetaXML::LightmanagerEnabledId;
_nameIdMap[Zeiss::MetaXML::FocusPosition] = Zeiss::MetaXML::FocusPositionId;
_nameIdMap[Zeiss::MetaXML::ImageCoordinateU] = Zeiss::MetaXML::ImageCoordinateUId;
//_nameIdMap[Zeiss::MetaXML::StageXPosition] = Zeiss::MetaXML::StageXPositionId;
_nameIdMap[Zeiss::MetaXML::ImageCoordinateV] = Zeiss::MetaXML::ImageCoordinateVId;
//_nameIdMap[Zeiss::MetaXML::StageYPosition] = Zeiss::MetaXML::StageYPositionId;
_nameIdMap[Zeiss::MetaXML::MicroscopeName] = Zeiss::MetaXML::MicroscopeNameId;
_nameIdMap[Zeiss::MetaXML::ObjectiveMagnification] = Zeiss::MetaXML::ObjectiveMagnificationId;
_nameIdMap[Zeiss::MetaXML::ObjectiveNA] = Zeiss::MetaXML::ObjectiveNAId;
_nameIdMap[Zeiss::MetaXML::MicroscopeIllumination] = Zeiss::MetaXML::MicroscopeIlluminationId;
_nameIdMap[Zeiss::MetaXML::ExtraShutter1] = Zeiss::MetaXML::ExtraShutter1Id;
_nameIdMap[Zeiss::MetaXML::ExtraShutter2] = Zeiss::MetaXML::ExtraShutter2Id;
_nameIdMap[Zeiss::MetaXML::ExtraShutter3] = Zeiss::MetaXML::ExtraShutter3Id;
_nameIdMap[Zeiss::MetaXML::ExtraFilter1] = Zeiss::MetaXML::ExtraFilter1Id;
_nameIdMap[Zeiss::MetaXML::ExtraFilter2] = Zeiss::MetaXML::ExtraFilter2Id;
_nameIdMap[Zeiss::MetaXML::ParfocalCorrection] = Zeiss::MetaXML::ParfocalCorrectionId;
_nameIdMap[Zeiss::MetaXML::ExtraShutter4] = Zeiss::MetaXML::ExtraShutter4Id;
_nameIdMap[Zeiss::MetaXML::ExtraShutter5] = Zeiss::MetaXML::ExtraShutter5Id;
_nameIdMap[Zeiss::MetaXML::ExtraShutter6] = Zeiss::MetaXML::ExtraShutter6Id;
_nameIdMap[Zeiss::MetaXML::ExtraFilter3] = Zeiss::MetaXML::ExtraFilter3Id;
_nameIdMap[Zeiss::MetaXML::ExtraFilter4] = Zeiss::MetaXML::ExtraFilter4Id;
_nameIdMap[Zeiss::MetaXML::ObjectivePosition] = Zeiss::MetaXML::ObjectivePositionId;
_nameIdMap[Zeiss::MetaXML::ObjectiveContrastMethod] = Zeiss::MetaXML::ObjectiveContrastMethodId;
_nameIdMap[Zeiss::MetaXML::ObjectiveImmersionType] = Zeiss::MetaXML::ObjectiveImmersionTypeId;
_nameIdMap[Zeiss::MetaXML::ReflectorPosition] = Zeiss::MetaXML::ReflectorPositionId;
_nameIdMap[Zeiss::MetaXML::TransmissionFilter1Position] = Zeiss::MetaXML::TransmissionFilter1PositionId;
_nameIdMap[Zeiss::MetaXML::TransmittedLightFilter1Position] = Zeiss::MetaXML::TransmittedLightFilter1PositionId;
_nameIdMap[Zeiss::MetaXML::TransmissionFilter2Position] = Zeiss::MetaXML::TransmissionFilter2PositionId;
_nameIdMap[Zeiss::MetaXML::TransmittedLightFilter2Position] = Zeiss::MetaXML::TransmittedLightFilter2PositionId;
_nameIdMap[Zeiss::MetaXML::ExcitationFilterPosition] = Zeiss::MetaXML::ExcitationFilterPositionId;
_nameIdMap[Zeiss::MetaXML::LampMirrorPosition] = Zeiss::MetaXML::LampMirrorPositionId;
_nameIdMap[Zeiss::MetaXML::ExtraFilter1Position] = Zeiss::MetaXML::ExtraFilter1PositionId;
_nameIdMap[Zeiss::MetaXML::ExtraFilter2Position] = Zeiss::MetaXML::ExtraFilter2PositionId;
_nameIdMap[Zeiss::MetaXML::ExtraFilter3Position] = Zeiss::MetaXML::ExtraFilter3PositionId;
_nameIdMap[Zeiss::MetaXML::ExtraFilter4Position] = Zeiss::MetaXML::ExtraFilter4PositionId;
_nameIdMap[Zeiss::MetaXML::LightmanagerMode] = Zeiss::MetaXML::LightmanagerModeId;
_nameIdMap[Zeiss::MetaXML::HalogenLampCalibrated] = Zeiss::MetaXML::HalogenLampCalibratedId;
_nameIdMap[Zeiss::MetaXML::CondenserNAGoSpeed] = Zeiss::MetaXML::CondenserNAGoSpeedId;
_nameIdMap[Zeiss::MetaXML::TransmittedLightFieldstopGoSpeed] = Zeiss::MetaXML::TransmittedLightFieldstopGoSpeedId;
_nameIdMap[Zeiss::MetaXML::OptovarGoSpeed] = Zeiss::MetaXML::OptovarGoSpeedId;
_nameIdMap[Zeiss::MetaXML::FocusCalibrated] = Zeiss::MetaXML::FocusCalibratedId;
_nameIdMap[Zeiss::MetaXML::FocusBasicPosition] = Zeiss::MetaXML::FocusBasicPositionId;
_nameIdMap[Zeiss::MetaXML::FocusPower] = Zeiss::MetaXML::FocusPowerId;
_nameIdMap[Zeiss::MetaXML::FocusBacklash] = Zeiss::MetaXML::FocusBacklashId;
_nameIdMap[Zeiss::MetaXML::FocusMeasurementOrigin] = Zeiss::MetaXML::FocusMeasurementOriginId;
_nameIdMap[Zeiss::MetaXML::FocusMeasurementDistance] = Zeiss::MetaXML::FocusMeasurementDistanceId;
_nameIdMap[Zeiss::MetaXML::FocusSpeed] = Zeiss::MetaXML::FocusSpeedId;
_nameIdMap[Zeiss::MetaXML::FocusGoSpeed] = Zeiss::MetaXML::FocusGoSpeedId;
_nameIdMap[Zeiss::MetaXML::FocusStepDistance] = Zeiss::MetaXML::FocusStepDistanceId;
_nameIdMap[Zeiss::MetaXML::FocusInitPosition] = Zeiss::MetaXML::FocusInitPositionId;
_nameIdMap[Zeiss::MetaXML::StageCalibrated] = Zeiss::MetaXML::StageCalibratedId;
_nameIdMap[Zeiss::MetaXML::StagePower] = Zeiss::MetaXML::StagePowerId;
_nameIdMap[Zeiss::MetaXML::StageXBacklash] = Zeiss::MetaXML::StageXBacklashId;
_nameIdMap[Zeiss::MetaXML::StageYBacklash] = Zeiss::MetaXML::StageYBacklashId;
_nameIdMap[Zeiss::MetaXML::StageXSpeed] = Zeiss::MetaXML::StageXSpeedId;
_nameIdMap[Zeiss::MetaXML::StageYSpeed] = Zeiss::MetaXML::StageYSpeedId;
_nameIdMap[Zeiss::MetaXML::StageSpeed] = Zeiss::MetaXML::StageSpeedId;
_nameIdMap[Zeiss::MetaXML::StageXGoSpeed] = Zeiss::MetaXML::StageXGoSpeedId;
_nameIdMap[Zeiss::MetaXML::StageYGoSpeed] = Zeiss::MetaXML::StageYGoSpeedId;
_nameIdMap[Zeiss::MetaXML::StageXStepDistance] = Zeiss::MetaXML::StageXStepDistanceId;
_nameIdMap[Zeiss::MetaXML::StageYStepDistance] = Zeiss::MetaXML::StageYStepDistanceId;
_nameIdMap[Zeiss::MetaXML::StageXInitPosition] = Zeiss::MetaXML::StageXInitPositionId;
_nameIdMap[Zeiss::MetaXML::StageYInitPosition] = Zeiss::MetaXML::StageYInitPositionId;
_nameIdMap[Zeiss::MetaXML::MicroscopeMagnification] = Zeiss::MetaXML::MicroscopeMagnificationId;
_nameIdMap[Zeiss::MetaXML::ReflectorMagnification] = Zeiss::MetaXML::ReflectorMagnificationId;
_nameIdMap[Zeiss::MetaXML::LampMirrorSelection] = Zeiss::MetaXML::LampMirrorSelectionId;
_nameIdMap[Zeiss::MetaXML::FocusDepth] = Zeiss::MetaXML::FocusDepthId;
_nameIdMap[Zeiss::MetaXML::MicroscopeType] = Zeiss::MetaXML::MicroscopeTypeId;
_nameIdMap[Zeiss::MetaXML::ObjectiveWorkingDistance] = Zeiss::MetaXML::ObjectiveWorkingDistanceId;
_nameIdMap[Zeiss::MetaXML::ReflectedLightApertureGoSpeed] = Zeiss::MetaXML::ReflectedLightApertureGoSpeedId;
_nameIdMap[Zeiss::MetaXML::ExternalShutter] = Zeiss::MetaXML::ExternalShutterId;
_nameIdMap[Zeiss::MetaXML::ObjectiveImmersionStopActive] = Zeiss::MetaXML::ObjectiveImmersionStopActiveId;
_nameIdMap[Zeiss::MetaXML::FocusStartSpeed] = Zeiss::MetaXML::FocusStartSpeedId;
_nameIdMap[Zeiss::MetaXML::FocusAcceleration] = Zeiss::MetaXML::FocusAccelerationId;
_nameIdMap[Zeiss::MetaXML::ReflectedLightFieldstop] = Zeiss::MetaXML::ReflectedLightFieldstopId;
_nameIdMap[Zeiss::MetaXML::ReflectedLightFieldstopGoSpeed] = Zeiss::MetaXML::ReflectedLightFieldstopGoSpeedId;
_nameIdMap[Zeiss::MetaXML::ReflectedLightFilter1] = Zeiss::MetaXML::ReflectedLightFilter1Id;
_nameIdMap[Zeiss::MetaXML::ReflectedLightFilter2] = Zeiss::MetaXML::ReflectedLightFilter2Id;
_nameIdMap[Zeiss::MetaXML::ReflectedLightFilter1Position] = Zeiss::MetaXML::ReflectedLightFilter1PositionId;
_nameIdMap[Zeiss::MetaXML::ReflectedLightFilter2Position] = Zeiss::MetaXML::ReflectedLightFilter2PositionId;
_nameIdMap[Zeiss::MetaXML::TransmittedLightAttenuator] = Zeiss::MetaXML::TransmittedLightAttenuatorId;
_nameIdMap[Zeiss::MetaXML::ReflectedLightAttenuator] = Zeiss::MetaXML::ReflectedLightAttenuatorId;
_nameIdMap[Zeiss::MetaXML::TransmittedLightShutter] = Zeiss::MetaXML::TransmittedLightShutterId;
_nameIdMap[Zeiss::MetaXML::TransmittedLightAttenuatorGoSpeed] = Zeiss::MetaXML::TransmittedLightAttenuatorGoSpeedId;
_nameIdMap[Zeiss::MetaXML::ReflectedLightAttenuatorGoSpeed] = Zeiss::MetaXML::ReflectedLightAttenuatorGoSpeedId;
_nameIdMap[Zeiss::MetaXML::ApotomeFocusPosition] = Zeiss::MetaXML::ApotomeFocusPositionId;
_nameIdMap[Zeiss::MetaXML::ApotomeFocusGoSpeed] = Zeiss::MetaXML::ApotomeFocusGoSpeedId;
_nameIdMap[Zeiss::MetaXML::ApotomePhasePosition] = Zeiss::MetaXML::ApotomePhasePositionId;
_nameIdMap[Zeiss::MetaXML::ApotomeSliderPosition] = Zeiss::MetaXML::ApotomeSliderPositionId;
_nameIdMap[Zeiss::MetaXML::ApotomeGridLinesPerMillimeter] = Zeiss::MetaXML::ApotomeGridLinesPerMillimeterId;
_nameIdMap[Zeiss::MetaXML::ApotomeWobbleMinPosition] = Zeiss::MetaXML::ApotomeWobbleMinPositionId;
_nameIdMap[Zeiss::MetaXML::ApotomeWobbleMaxPosition] = Zeiss::MetaXML::ApotomeWobbleMaxPositionId;
_nameIdMap[Zeiss::MetaXML::ApotomeWobbleSpeed] = Zeiss::MetaXML::ApotomeWobbleSpeedId;
_nameIdMap[Zeiss::MetaXML::TransmittedLightVirtualFilterPosition] = Zeiss::MetaXML::TransmittedLightVirtualFilterPositionId;
_nameIdMap[Zeiss::MetaXML::TransmittedLightVirtualFilter] = Zeiss::MetaXML::TransmittedLightVirtualFilterId;
_nameIdMap[Zeiss::MetaXML::ReflectedLightVirtualFilterPosition] = Zeiss::MetaXML::ReflectedLightVirtualFilterPositionId;
_nameIdMap[Zeiss::MetaXML::ReflectedLightVirtualFilter] = Zeiss::MetaXML::ReflectedLightVirtualFilterId;
_nameIdMap[Zeiss::MetaXML::ReflectedLightHALMode] = Zeiss::MetaXML::ReflectedLightHALModeId;
_nameIdMap[Zeiss::MetaXML::ReflectedLightHALVoltage] = Zeiss::MetaXML::ReflectedLightHALVoltageId;
_nameIdMap[Zeiss::MetaXML::ReflectedLightHALColourTemperature] = Zeiss::MetaXML::ReflectedLightHALColourTemperatureId;
_nameIdMap[Zeiss::MetaXML::ContrastmanagerMode] = Zeiss::MetaXML::ContrastmanagerModeId;
_nameIdMap[Zeiss::MetaXML::DazzleProtection] = Zeiss::MetaXML::DazzleProtectionId;
_nameIdMap[Zeiss::MetaXML::StageXCalibrated] = Zeiss::MetaXML::StageXCalibratedId;
_nameIdMap[Zeiss::MetaXML::StageYCalibrated] = Zeiss::MetaXML::StageYCalibratedId;
_nameIdMap[Zeiss::MetaXML::StageXPower] = Zeiss::MetaXML::StageXPowerId;
_nameIdMap[Zeiss::MetaXML::StageYPower] = Zeiss::MetaXML::StageYPowerId;
_nameIdMap[Zeiss::MetaXML::StageXStartSpeed] = Zeiss::MetaXML::StageXStartSpeedId;
_nameIdMap[Zeiss::MetaXML::StageYStartSpeed] = Zeiss::MetaXML::StageYStartSpeedId;
_nameIdMap[Zeiss::MetaXML::StageXAcceleration] = Zeiss::MetaXML::StageXAccelerationId;
_nameIdMap[Zeiss::MetaXML::StageYAcceleration] = Zeiss::MetaXML::StageYAccelerationId;
_nameIdMap[Zeiss::MetaXML::StageStartSpeed] = Zeiss::MetaXML::StageStartSpeedId;
_nameIdMap[Zeiss::MetaXML::StageAcceleration] = Zeiss::MetaXML::StageAccelerationId;
_nameIdMap[Zeiss::MetaXML::Zoom] = Zeiss::MetaXML::ZoomId;
_nameIdMap[Zeiss::MetaXML::ZoomGoSpeed] = Zeiss::MetaXML::ZoomGoSpeedId;
_nameIdMap[Zeiss::MetaXML::LightZoom] = Zeiss::MetaXML::LightZoomId;
_nameIdMap[Zeiss::MetaXML::LightZoomGoSpeed] = Zeiss::MetaXML::LightZoomGoSpeedId;
_nameIdMap[Zeiss::MetaXML::LightZoomCoupled] = Zeiss::MetaXML::LightZoomCoupledId;
_nameIdMap[Zeiss::MetaXML::TransmittedLightHALMode] = Zeiss::MetaXML::TransmittedLightHALModeId;
_nameIdMap[Zeiss::MetaXML::TransmittedLightHALVoltage] = Zeiss::MetaXML::TransmittedLightHALVoltageId;
_nameIdMap[Zeiss::MetaXML::TransmittedLightHALColourTemperature] = Zeiss::MetaXML::TransmittedLightHALColourTemperatureId;
_nameIdMap[Zeiss::MetaXML::ReflectedLightCLMode] = Zeiss::MetaXML::ReflectedLightCLModeId;
_nameIdMap[Zeiss::MetaXML::ReflectedLightCLIntensity] = Zeiss::MetaXML::ReflectedLightCLIntensityId;
_nameIdMap[Zeiss::MetaXML::ReflectedLightCLColourTemperature] = Zeiss::MetaXML::ReflectedLightCLColourTemperatureId;
_nameIdMap[Zeiss::MetaXML::TransmittedLightCLMode] = Zeiss::MetaXML::TransmittedLightCLModeId;
_nameIdMap[Zeiss::MetaXML::TransmittedLightCLIntensity] = Zeiss::MetaXML::TransmittedLightCLIntensityId;
_nameIdMap[Zeiss::MetaXML::TransmittedLightCLColourTemperature] = Zeiss::MetaXML::TransmittedLightCLColourTemperatureId;
_nameIdMap[Zeiss::MetaXML::InfinitySpaceChangerPosition] = Zeiss::MetaXML::InfinitySpaceChangerPositionId;
_nameIdMap[Zeiss::MetaXML::SidePortPercent] = Zeiss::MetaXML::SidePortPercentId;
_nameIdMap[Zeiss::MetaXML::TwoTvVisCamChangerPosition] = Zeiss::MetaXML::TwoTvVisCamChangerPositionId;
_nameIdMap[Zeiss::MetaXML::OcularPercent] = Zeiss::MetaXML::OcularPercentId;
_nameIdMap[Zeiss::MetaXML::TwoTvCamerasChangerPosition] = Zeiss::MetaXML::TwoTvCamerasChangerPositionId;
_nameIdMap[Zeiss::MetaXML::TopPortPercent] = Zeiss::MetaXML::TopPortPercentId;
_nameIdMap[Zeiss::MetaXML::OcularShutter] = Zeiss::MetaXML::OcularShutterId;
_nameIdMap[Zeiss::MetaXML::TwoTvCamerasChangerCube] = Zeiss::MetaXML::TwoTvCamerasChangerCubeId;
_nameIdMap[Zeiss::MetaXML::LightWaveLength] = Zeiss::MetaXML::LightWaveLengthId;
_nameIdMap[Zeiss::MetaXML::OcularMagnification] = Zeiss::MetaXML::OcularMagnificationId;
_nameIdMap[Zeiss::MetaXML::CameraAdapterMagnification] = Zeiss::MetaXML::CameraAdapterMagnificationId;
_nameIdMap[Zeiss::MetaXML::MicroscopePort] = Zeiss::MetaXML::MicroscopePortId;
_nameIdMap[Zeiss::MetaXML::OcularTotalMagnification] = Zeiss::MetaXML::OcularTotalMagnificationId;
_nameIdMap[Zeiss::MetaXML::FieldOfView] = Zeiss::MetaXML::FieldOfViewId;
_nameIdMap[Zeiss::MetaXML::Ocular] = Zeiss::MetaXML::OcularId;
_nameIdMap[Zeiss::MetaXML::CameraAdapter] = Zeiss::MetaXML::CameraAdapterId;
_nameIdMap[Zeiss::MetaXML::StageJoystickEnabled] = Zeiss::MetaXML::StageJoystickEnabledId;
_nameIdMap[Zeiss::MetaXML::ContrastmanagerContrastMethod] = Zeiss::MetaXML::ContrastmanagerContrastMethodId;
_nameIdMap[Zeiss::MetaXML::StageXJoystickEnabled] = Zeiss::MetaXML::StageXJoystickEnabledId;
_nameIdMap[Zeiss::MetaXML::StageYJoystickEnabled] = Zeiss::MetaXML::StageYJoystickEnabledId;
_nameIdMap[Zeiss::MetaXML::CameraFrameLeft] = Zeiss::MetaXML::CameraFrameLeftId;
_nameIdMap[Zeiss::MetaXML::CameraFrameTop] = Zeiss::MetaXML::CameraFrameTopId;
_nameIdMap[Zeiss::MetaXML::CameraFrameWidth] = Zeiss::MetaXML::CameraFrameWidthId;
_nameIdMap[Zeiss::MetaXML::CameraFrameHeight] = Zeiss::MetaXML::CameraFrameHeightId;
_nameIdMap[Zeiss::MetaXML::CameraFrameBinning] = Zeiss::MetaXML::CameraFrameBinningId;
_nameIdMap[Zeiss::MetaXML::CameraFrameFull] = Zeiss::MetaXML::CameraFrameFullId;
_nameIdMap[Zeiss::MetaXML::CameraFramePixelDistance] = Zeiss::MetaXML::CameraFramePixelDistanceId;
_nameIdMap[Zeiss::MetaXML::DataFormatUseScaling] = Zeiss::MetaXML::DataFormatUseScalingId;
_nameIdMap[Zeiss::MetaXML::CameraFrameImageOrientation] = Zeiss::MetaXML::CameraFrameImageOrientationId;
_nameIdMap[Zeiss::MetaXML::MeteorChannelInput] = Zeiss::MetaXML::MeteorChannelInputId;
_nameIdMap[Zeiss::MetaXML::MeteorChannelSync] = Zeiss::MetaXML::MeteorChannelSyncId;
_nameIdMap[Zeiss::MetaXML::CameraWhiteBalanceRed] = Zeiss::MetaXML::CameraWhiteBalanceRedId;
_nameIdMap[Zeiss::MetaXML::CameraWhiteBalanceGreen] = Zeiss::MetaXML::CameraWhiteBalanceGreenId;
_nameIdMap[Zeiss::MetaXML::CameraWhiteBalanceBlue] = Zeiss::MetaXML::CameraWhiteBalanceBlueId;
_nameIdMap[Zeiss::MetaXML::CameraFrameScalingFactor] = Zeiss::MetaXML::CameraFrameScalingFactorId;
_nameIdMap[Zeiss::MetaXML::MeteorCameraType] = Zeiss::MetaXML::MeteorCameraTypeId;
_nameIdMap[Zeiss::MetaXML::CameraExposureTimeValue] = Zeiss::MetaXML::CameraExposureTimeValueId;
_nameIdMap[Zeiss::MetaXML::CameraExposureTimeAutoCalculate] = Zeiss::MetaXML::CameraExposureTimeAutoCalculateId;
_nameIdMap[Zeiss::MetaXML::MeteorGainValue] = Zeiss::MetaXML::MeteorGainValueId;
_nameIdMap[Zeiss::MetaXML::MeteorGainAutomatic] = Zeiss::MetaXML::MeteorGainAutomaticId;
_nameIdMap[Zeiss::MetaXML::MeteorAdjustHue] = Zeiss::MetaXML::MeteorAdjustHueId;
_nameIdMap[Zeiss::MetaXML::MeteorAdjustSaturation] = Zeiss::MetaXML::MeteorAdjustSaturationId;
_nameIdMap[Zeiss::MetaXML::MeteorAdjustRedLow] = Zeiss::MetaXML::MeteorAdjustRedLowId;
_nameIdMap[Zeiss::MetaXML::MeteorAdjustGreenLow] = Zeiss::MetaXML::MeteorAdjustGreenLowId;
_nameIdMap[Zeiss::MetaXML::MeteorAdjustBlueLow] = Zeiss::MetaXML::MeteorAdjustBlueLowId;
_nameIdMap[Zeiss::MetaXML::MeteorAdjustRedHigh] = Zeiss::MetaXML::MeteorAdjustRedHighId;
_nameIdMap[Zeiss::MetaXML::MeteorAdjustGreenHigh] = Zeiss::MetaXML::MeteorAdjustGreenHighId;
_nameIdMap[Zeiss::MetaXML::MeteorAdjustBlueHigh] = Zeiss::MetaXML::MeteorAdjustBlueHighId;
_nameIdMap[Zeiss::MetaXML::MeteorAdjustWhiteRefEnable] = Zeiss::MetaXML::MeteorAdjustWhiteRefEnableId;
_nameIdMap[Zeiss::MetaXML::CameraExposureTimeCalculationControl] = Zeiss::MetaXML::CameraExposureTimeCalculationControlId;
_nameIdMap[Zeiss::MetaXML::AxioCamFadingCorrectionEnable] = Zeiss::MetaXML::AxioCamFadingCorrectionEnableId;
_nameIdMap[Zeiss::MetaXML::AxioCamSuspendLiveTimeout] = Zeiss::MetaXML::AxioCamSuspendLiveTimeoutId;
_nameIdMap[Zeiss::MetaXML::CameraLiveImage] = Zeiss::MetaXML::CameraLiveImageId;
_nameIdMap[Zeiss::MetaXML::CameraLiveEnabled] = Zeiss::MetaXML::CameraLiveEnabledId;
_nameIdMap[Zeiss::MetaXML::LiveImageSyncObjectName] = Zeiss::MetaXML::LiveImageSyncObjectNameId;
_nameIdMap[Zeiss::MetaXML::CameraLiveSpeed] = Zeiss::MetaXML::CameraLiveSpeedId;
_nameIdMap[Zeiss::MetaXML::CameraImage] = Zeiss::MetaXML::CameraImageId;
_nameIdMap[Zeiss::MetaXML::CameraImageWidth] = Zeiss::MetaXML::CameraImageWidthId;
_nameIdMap[Zeiss::MetaXML::CameraImageHeight] = Zeiss::MetaXML::CameraImageHeightId;
_nameIdMap[Zeiss::MetaXML::CameraImagePixelType] = Zeiss::MetaXML::CameraImagePixelTypeId;
_nameIdMap[Zeiss::MetaXML::CameraImageShMemoryName] = Zeiss::MetaXML::CameraImageShMemoryNameId;
_nameIdMap[Zeiss::MetaXML::CameraLiveImageWidth] = Zeiss::MetaXML::CameraLiveImageWidthId;
_nameIdMap[Zeiss::MetaXML::CameraLiveImageHeight] = Zeiss::MetaXML::CameraLiveImageHeightId;
_nameIdMap[Zeiss::MetaXML::CameraLiveImagePixelType] = Zeiss::MetaXML::CameraLiveImagePixelTypeId;
_nameIdMap[Zeiss::MetaXML::CameraLiveImageShMemoryName] = Zeiss::MetaXML::CameraLiveImageShMemoryNameId;
_nameIdMap[Zeiss::MetaXML::CameraLiveMaximumSpeed] = Zeiss::MetaXML::CameraLiveMaximumSpeedId;
_nameIdMap[Zeiss::MetaXML::CameraLiveBinning] = Zeiss::MetaXML::CameraLiveBinningId;
_nameIdMap[Zeiss::MetaXML::CameraLiveGainValue] = Zeiss::MetaXML::CameraLiveGainValueId;
_nameIdMap[Zeiss::MetaXML::CameraLiveExposureTimeValue] = Zeiss::MetaXML::CameraLiveExposureTimeValueId;
_nameIdMap[Zeiss::MetaXML::CameraLiveScalingFactor] = Zeiss::MetaXML::CameraLiveScalingFactorId;
_nameIdMap[Zeiss::MetaXML::CameraCoAcqFastMode] = Zeiss::MetaXML::CameraCoAcqFastModeId;
_nameIdMap[Zeiss::MetaXML::ImageIndexU] = Zeiss::MetaXML::ImageIndexUId;
_nameIdMap[Zeiss::MetaXML::ImageIndexV] = Zeiss::MetaXML::ImageIndexVId;
_nameIdMap[Zeiss::MetaXML::ImageIndexZ] = Zeiss::MetaXML::ImageIndexZId;
_nameIdMap[Zeiss::MetaXML::ImageIndexC] = Zeiss::MetaXML::ImageIndexCId;
_nameIdMap[Zeiss::MetaXML::ImageIndexT] = Zeiss::MetaXML::ImageIndexTId;
_nameIdMap[Zeiss::MetaXML::ImageIndexP] = Zeiss::MetaXML::ImageIndexPId;
_nameIdMap[Zeiss::MetaXML::ImageIndexA] = Zeiss::MetaXML::ImageIndexAId;
_nameIdMap[Zeiss::MetaXML::ImageCountP] = Zeiss::MetaXML::ImageCountPId;
_nameIdMap[Zeiss::MetaXML::ImageCountA] = Zeiss::MetaXML::ImageCountAId;
_nameIdMap[Zeiss::MetaXML::ImageIndexS] = Zeiss::MetaXML::ImageIndexSId;
_nameIdMap[Zeiss::MetaXML::ImageIndexRaw] = Zeiss::MetaXML::ImageIndexRawId;
_nameIdMap[Zeiss::MetaXML::ImageCountZ] = Zeiss::MetaXML::ImageCountZId;
_nameIdMap[Zeiss::MetaXML::ImageCountC] = Zeiss::MetaXML::ImageCountCId;
_nameIdMap[Zeiss::MetaXML::ImageCountT] = Zeiss::MetaXML::ImageCountTId;
_nameIdMap[Zeiss::MetaXML::ImageCountU] = Zeiss::MetaXML::ImageCountUId;
_nameIdMap[Zeiss::MetaXML::ImageCountV] = Zeiss::MetaXML::ImageCountVId;
_nameIdMap[Zeiss::MetaXML::ImageCountS] = Zeiss::MetaXML::ImageCountSId;
_nameIdMap[Zeiss::MetaXML::ImageOrgCoordinateU] = Zeiss::MetaXML::ImageOrgCoordinateUId;
_nameIdMap[Zeiss::MetaXML::ImageOrgCoordinateV] = Zeiss::MetaXML::ImageOrgCoordinateVId;
_nameIdMap[Zeiss::MetaXML::LayerDrawFlags] = Zeiss::MetaXML::LayerDrawFlagsId;
_nameIdMap[Zeiss::MetaXML::JobGroup] = Zeiss::MetaXML::JobGroupId;
_nameIdMap[Zeiss::MetaXML::JobName] = Zeiss::MetaXML::JobNameId;
_nameIdMap[Zeiss::MetaXML::JobInfo] = Zeiss::MetaXML::JobInfoId;
_nameIdMap[Zeiss::MetaXML::JobProgress] = Zeiss::MetaXML::JobProgressId;
_nameIdMap[Zeiss::MetaXML::JobStatus] = Zeiss::MetaXML::JobStatusId;
_nameIdMap[Zeiss::MetaXML::JobId] = Zeiss::MetaXML::JobIdId;
_nameIdMap[Zeiss::MetaXML::JobRemainingTime] = Zeiss::MetaXML::JobRemainingTimeId;
_nameIdMap[Zeiss::MetaXML::AcquisitionTimeInDouble] = Zeiss::MetaXML::AcquisitionTimeInDoubleId;
_nameIdMap[Zeiss::MetaXML::RelFocusPosition] = Zeiss::MetaXML::RelFocusPositionId;
_nameIdMap[Zeiss::MetaXML::SidePortTurretposition] = Zeiss::MetaXML::SidePortTurretpositionId;
_nameIdMap[Zeiss::MetaXML::SidePortLeftPercent] = Zeiss::MetaXML::SidePortLeftPercentId;
_nameIdMap[Zeiss::MetaXML::SidePortRightPercent] = Zeiss::MetaXML::SidePortRightPercentId;
_nameIdMap[Zeiss::MetaXML::BasePortSliderPortPercent] = Zeiss::MetaXML::BasePortSliderPortPercentId;
_nameIdMap[Zeiss::MetaXML::SidePortLeftFunction] = Zeiss::MetaXML::SidePortLeftFunctionId;
_nameIdMap[Zeiss::MetaXML::SidePortRightFunction] = Zeiss::MetaXML::SidePortRightFunctionId;
_nameIdMap[Zeiss::MetaXML::BasePortSliderPortFunction] = Zeiss::MetaXML::BasePortSliderPortFunctionId;
_nameIdMap[Zeiss::MetaXML::SidePortLightPath] = Zeiss::MetaXML::SidePortLightPathId;
_nameIdMap[Zeiss::MetaXML::SidePortLightPathID] = Zeiss::MetaXML::SidePortLightPathIDId;
_nameIdMap[Zeiss::MetaXML::ObjectiveID] = Zeiss::MetaXML::ObjectiveIDId;
_nameIdMap[Zeiss::MetaXML::ReflectorID] = Zeiss::MetaXML::ReflectorIDId;
}
// -----------------------------------------------------------------------------
//
//------------------------------------------------------------------------------
void ZeissTagMapping::initFactoryMap()
{
_idFactoryMap[Zeiss::MetaXML::ImageDataMappingTableId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageDataMappingLowId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageDataMappingHighId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageDataMappingAutoRangeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::DocumentThumbnailId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageDataMappingGammaId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageDataHistoMaxId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageOverExposureId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageRelativeTimeFirstId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageRelativeTime1Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageRelativeTime2Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageRelativeTime3Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageRelativeTime4Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageRelativeTimeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageBaseTimeFirstId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageBaseTime1Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageBaseTime2Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageBaseTime3Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageBaseTime4Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageBaseTimeLast_reservedId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::RelFocusPosition1Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::RelFocusPosition2Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageObjectTypeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageWidthId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageHeightId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageCountRawId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImagePixelTypeId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CountId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CompressionFactorForSaveId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::DocumentSaveFlagsId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageTimestampCommentsId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::DocumentSubTypeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraImageValidBitsPerPixelId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageMemoryUsageId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageMSBShiftForPixelsId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ScaleFactorForWidthId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ScaleTypeForWidthId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ScaleWidthId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ScaleFactorForHeightId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ScaleTypeForHeightId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ScaleHeightId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ScaleFactorForDepthId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ScaleTypeForDepthId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ScaleDepthId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ScalingParentId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::EventLogTypeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::EventLogDateId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::EventLogCodeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::EventLogSourceNameId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::EventLogMessageId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::AcquisitionGroupId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraImageAcquisitionTimeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraValidBitsPerPixelId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MonoReferenceLowId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MonoReferenceHighId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::RedReferenceLowId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::RedReferenceHighId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::GreenReferenceLowId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::GreenReferenceHighId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::BlueReferenceLowId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::BlueReferenceHighId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::GrabberNameId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraNameId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraTriggerSignalTypeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraTriggerEnableId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::GrabberTimeoutId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::AcquisitionTimeInDoubleId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MultiChannelEnabledId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MultiChannelColorId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MultiChannelWeightId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MultiChannelNameId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::DocumentInformationGroupId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::DocumentTitleId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::DocumentAuthorId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::DocumentKeywordsId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::DocumentCommentsId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::DocumentSampleIDId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::DocumentSubjectId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::RevisionNumberId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::DocumentPathId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FileLinkId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::DocumentTypeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FileMediumId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FileIDId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::DocumentFileNameId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FileDateId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FileSizeId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::DocumentNameId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FileAttributesId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ProjectGroupId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::DateId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::DocumentLastSavedById] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::UserCompanyId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::UserCompanyLogoId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::UserIdId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::UserNameId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::UserCityId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::UserAddressId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::UserStateId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::UserPhoneId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::UserFaxId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ObjectiveId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::OptovarId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectorId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CondenserContrastId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmissionFilter1Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmittedLightFilter1Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmissionFilter2Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmittedLightFilter2Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::InternalShutterId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectedLightShutterId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CondenserFrontlensId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ExcitationFilterId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmittedLightFieldstopId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectedLightApertureId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CondenserNAId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::LightPathId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::HalogenLampOnId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::HalogenLampModeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::HalogenLampVoltageId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FluoLampModeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FluoLampIntensityId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::LightmanagerEnabledId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FocusPositionId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageCoordinateUId] = FloatZeissMetaFactory::NewZeissMetaFactory();
//_idFactoryMap[Zeiss::MetaXML::StageXPositionId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageCoordinateVId] = FloatZeissMetaFactory::NewZeissMetaFactory();
//_idFactoryMap[Zeiss::MetaXML::StageYPositionId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MicroscopeNameId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ObjectiveMagnificationId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ObjectiveNAId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MicroscopeIlluminationId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ExtraShutter1Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ExtraShutter2Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ExtraShutter3Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ExtraFilter1Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ExtraFilter2Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ParfocalCorrectionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ExtraShutter4Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ExtraShutter5Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ExtraShutter6Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ExtraFilter3Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ExtraFilter4Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ObjectivePositionId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ObjectiveContrastMethodId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ObjectiveImmersionTypeId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectorPositionId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmissionFilter1PositionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmittedLightFilter1PositionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmissionFilter2PositionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmittedLightFilter2PositionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ExcitationFilterPositionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::LampMirrorPositionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ExtraFilter1PositionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ExtraFilter2PositionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ExtraFilter3PositionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ExtraFilter4PositionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::LightmanagerModeId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::HalogenLampCalibratedId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CondenserNAGoSpeedId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmittedLightFieldstopGoSpeedId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::OptovarGoSpeedId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FocusCalibratedId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FocusBasicPositionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FocusPowerId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FocusBacklashId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FocusMeasurementOriginId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FocusMeasurementDistanceId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FocusSpeedId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FocusGoSpeedId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FocusStepDistanceId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FocusInitPositionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageCalibratedId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StagePowerId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageXBacklashId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageYBacklashId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageXSpeedId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageYSpeedId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageSpeedId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageXGoSpeedId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageYGoSpeedId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageXStepDistanceId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageYStepDistanceId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageXInitPositionId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageYInitPositionId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MicroscopeMagnificationId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectorMagnificationId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::LampMirrorSelectionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FocusDepthId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MicroscopeTypeId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ObjectiveWorkingDistanceId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectedLightApertureGoSpeedId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ExternalShutterId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ObjectiveImmersionStopActiveId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FocusStartSpeedId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FocusAccelerationId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectedLightFieldstopId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectedLightFieldstopGoSpeedId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectedLightFilter1Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectedLightFilter2Id] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectedLightFilter1PositionId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectedLightFilter2PositionId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmittedLightAttenuatorId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectedLightAttenuatorId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmittedLightShutterId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmittedLightAttenuatorGoSpeedId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectedLightAttenuatorGoSpeedId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ApotomeFocusPositionId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ApotomeFocusGoSpeedId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ApotomePhasePositionId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ApotomeSliderPositionId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ApotomeGridLinesPerMillimeterId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ApotomeWobbleMinPositionId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ApotomeWobbleMaxPositionId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ApotomeWobbleSpeedId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmittedLightVirtualFilterPositionId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmittedLightVirtualFilterId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectedLightVirtualFilterPositionId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectedLightVirtualFilterId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectedLightHALModeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectedLightHALVoltageId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectedLightHALColourTemperatureId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ContrastmanagerModeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::DazzleProtectionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageXCalibratedId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageYCalibratedId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageXPowerId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageYPowerId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageXStartSpeedId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageYStartSpeedId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageXAccelerationId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageYAccelerationId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageStartSpeedId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageAccelerationId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ZoomId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ZoomGoSpeedId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::LightZoomId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::LightZoomGoSpeedId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::LightZoomCoupledId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmittedLightHALModeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmittedLightHALVoltageId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmittedLightHALColourTemperatureId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectedLightCLModeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectedLightCLIntensityId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectedLightCLColourTemperatureId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmittedLightCLModeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmittedLightCLIntensityId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TransmittedLightCLColourTemperatureId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::InfinitySpaceChangerPositionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::SidePortPercentId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TwoTvVisCamChangerPositionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::OcularPercentId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TwoTvCamerasChangerPositionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TopPortPercentId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::OcularShutterId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::TwoTvCamerasChangerCubeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::LightWaveLengthId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::OcularMagnificationId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraAdapterMagnificationId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MicroscopePortId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::OcularTotalMagnificationId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::FieldOfViewId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::OcularId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraAdapterId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageJoystickEnabledId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ContrastmanagerContrastMethodId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageXJoystickEnabledId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::StageYJoystickEnabledId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraFrameLeftId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraFrameTopId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraFrameWidthId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraFrameHeightId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraFrameBinningId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraFrameFullId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraFramePixelDistanceId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::DataFormatUseScalingId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraFrameImageOrientationId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MeteorChannelInputId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MeteorChannelSyncId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraWhiteBalanceRedId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraWhiteBalanceGreenId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraWhiteBalanceBlueId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraFrameScalingFactorId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MeteorCameraTypeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraExposureTimeValueId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraExposureTimeAutoCalculateId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MeteorGainValueId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MeteorGainAutomaticId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MeteorAdjustHueId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MeteorAdjustSaturationId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MeteorAdjustRedLowId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MeteorAdjustGreenLowId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MeteorAdjustBlueLowId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MeteorAdjustRedHighId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MeteorAdjustGreenHighId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MeteorAdjustBlueHighId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::MeteorAdjustWhiteRefEnableId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraExposureTimeCalculationControlId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::AxioCamFadingCorrectionEnableId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::AxioCamSuspendLiveTimeoutId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraLiveImageId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraLiveEnabledId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::LiveImageSyncObjectNameId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraLiveSpeedId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraImageId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraImageWidthId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraImageHeightId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraImagePixelTypeId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraImageShMemoryNameId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraLiveImageWidthId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraLiveImageHeightId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraLiveImagePixelTypeId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraLiveImageShMemoryNameId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraLiveMaximumSpeedId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraLiveBinningId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraLiveGainValueId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraLiveExposureTimeValueId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraLiveScalingFactorId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::CameraCoAcqFastModeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageIndexUId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageIndexVId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageIndexZId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageIndexCId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageIndexTId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageIndexPId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageIndexAId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageCountPId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageCountAId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageIndexSId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageIndexRawId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageCountZId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageCountCId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageCountTId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageCountUId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageCountVId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageCountSId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageOrgCoordinateUId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ImageOrgCoordinateVId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::LayerDrawFlagsId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::JobGroupId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::JobNameId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::JobInfoId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::JobProgressId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::JobStatusId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::JobIdId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::JobRemainingTimeId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::AcquisitionTimeInDoubleId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::RelFocusPositionId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::SidePortTurretpositionId] = Int32ZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::SidePortLeftPercentId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::SidePortRightPercentId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::BasePortSliderPortPercentId] = FloatZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::SidePortLeftFunctionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::SidePortRightFunctionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::BasePortSliderPortFunctionId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::SidePortLightPathId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::SidePortLightPathIDId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ObjectiveIDId] = StringZeissMetaFactory::NewZeissMetaFactory();
_idFactoryMap[Zeiss::MetaXML::ReflectorIDId] = StringZeissMetaFactory::NewZeissMetaFactory();
}
