INCLUDE(CheckIncludeFile)
INCLUDE(CheckSymbolExists)
INCLUDE(CheckStructMember)
INCLUDE(CheckTypeSize)
INCLUDE(${CMAKE_ROOT}/Modules/TestBigEndian.cmake)

CHECK_INCLUDE_FILE(dlfcn.h      HAVE_DLFCN_H)
CHECK_INCLUDE_FILE(fcntl.h      HAVE_FCNTL_H)
CHECK_INCLUDE_FILE(inittypes.h  HAVE_INITTYPES_H)
CHECK_INCLUDE_FILE(memory.h     HAVE_MEMORY_H)
CHECK_INCLUDE_FILE(stdio.h      HAVE_STDIO_H)   
CHECK_INCLUDE_FILE(stdlib.h     HAVE_STDLIB_H)   
CHECK_INCLUDE_FILE(string.h     HAVE_STRING_H)   
CHECK_INCLUDE_FILE(strings.h    HAVE_STRINGS_H)   
CHECK_INCLUDE_FILE(sys/types.h  HAVE_SYS_TYPES_H)
CHECK_INCLUDE_FILE(sys/stat.h   HAVE_SYS_STAT_H)
CHECK_INCLUDE_FILE(unistd.h     HAVE_UNISTD_H)  

SET (HAVE_BCOPY)     
CHECK_SYMBOL_EXISTS(getpagesize  ""                 HAVE_GETPAGESIZE)    
CHECK_SYMBOL_EXISTS(memmove      "string.h"         HAVE_MEMMOVE)       
CHECK_SYMBOL_EXISTS(mmap         "sys/mman.h"        HAVE_MMAP)          

SET(LINUX_LFS 0)
IF(CMAKE_SYSTEM MATCHES "Linux-([3-9]\\.[0-9]|2\\.[4-9])\\.")
  OPTION(EXPAT_ENABLE_LINUX_LFS 
    "Enable support for large (64-bit) files on Linux." ON)
  IF(EXPAT_ENABLE_LINUX_LFS)
    SET(LINUX_LFS 1)
  ENDIF(EXPAT_ENABLE_LINUX_LFS)
ENDIF(CMAKE_SYSTEM MATCHES "Linux-([3-9]\\.[0-9]|2\\.[4-9])\\.")
SET(EXPAT_EXTRA_FLAGS)
IF(LINUX_LFS)
  SET(EXPAT_EXTRA_FLAGS -D_FILE_OFFSET_BITS=64)
  SET(CMAKE_REQUIRED_DEFINITIONS ${EXPAT_EXTRA_FLAGS})
ENDIF(LINUX_LFS)
ADD_DEFINITIONS(${EXPAT_EXTRA_FLAGS})

CHECK_TYPE_SIZE(off_t  SIZEOF_OFF_T)
#MESSAGE (STATUS "Size of off_t ${SIZEOF_OFF_T}")
IF (SIZEOF_OFF_T)
  SET (HAVE_OFF_T 1)
ELSEIF (SIZEOF_OFF_T)
  SET (HAVE_OFF_T 0)
  SET(off_t "long")
ENDIF(SIZEOF_OFF_T)

TEST_BIG_ENDIAN(HOST_BIGENDIAN)
IF ( HOST_BIGENDIAN)
 SET (BYTEORDER 4321)
 SET (WORDS_BIGENDIAN 1)
ELSE (HOST_BIGENDIAN)
   SET (BYTEORDER 1234)
   SET (WORDS_BIGENDIAN 0)
ENDIF ( HOST_BIGENDIAN)

SET (const "const")
# currently only win32 
SET (STDC_HEADERS 1)
SET (XML_CONTEXT_BYTES 1)
SET (XML_DTD)
SET (XML_NS)

IF ( WIN32 )
  set (__func__ "__FUNCTION__")
ELSE (WIN32)

ENDIF ( WIN32 )


# missing:
# HAVE_ABSTRACT_SOCKETS
# DBUS_HAVE_GCC33_GCOV

CHECK_TYPE_SIZE("short"     SIZEOF_SHORT)
CHECK_TYPE_SIZE("int"       SIZEOF_INT)
CHECK_TYPE_SIZE("long long" SIZEOF_LONG_LONG)
CHECK_TYPE_SIZE("__int64"   SIZEOF___INT64)

FIND_PACKAGE(Doxygen)
FIND_PROGRAM(EXPAT_XMLTO xmlto)
